#!/bin/sh

#********************************************************************************
# Licensed Materials - Property of IBM
# IBM Quick Deployer
# (c) Copyright IBM Corporation 2015. All Rights Reserved.
#
# U.S. Government Users Restricted Rights:
# Use, duplication or disclosure restricted by GSA ADP Schedule
# Contract with IBM Corp.
#
#********************************************************************************


#############################################################################
# Name: getNodeName.sh

. /etc/env.properties
This_DIR=`pwd -P`

scriptName=$0


# check inputs
validInputs="[AGENT_HOME] [UCDSERVER] [AUTH_TOKEN] [APPLICATION_ID] [ENVIRONMENT_ID] [COMPONENT_ID] [AGENT_ID]"

if [ $# == 0 ]; then
  echo "ERROR: script "${scriptName}" has no input parameters"
  echo "should be "${validInputs}
  exit 1
elif [ $# != 7 ]; then
  echo "ERROR: script "${scriptName}" has wrong number ["$#"] of input parameters"
  echo "should be "${validInputs}
  exit 1
else
  echo "correct number of inputs"
  AGENT_HOME=$1
  UCDSERVER=$2
  AUTH_TOKEN=$3
  APPLICATION_ID=$4
  ENVIRONMENT_ID=$5
  COMPONENT_ID=$6
  AGENT_ID=$7
fi

echo "AGENT_HOME ["${AGENT_HOME}"]"
echo "UCDSERVER ["${UCDSERVER}"]"
echo "AUTH_TOKEN ["${AUTH_TOKEN}"]"
echo "APPLICATION_ID ["${APPLICATION_ID}"]"
echo "ENVIRONMENT_ID ["${ENVIRONMENT_ID}"]"
echo "COMPONENT_ID ["${COMPONENT_ID}"]"
echo "AGENT_ID ["${AGENT_ID}"]"


WAS_HOME=$WAS_PROFILE_ROOT

echo "extract WAS Profile NODENAME"
pyOut=`su - $OSUserName -c "$WAS_HOME/bin/wsadmin.sh -lang jython -f $This_DIR/getNodeName.jy"`
if [ $? -ne 0 ]; then
  echo "ERROR: script "${scriptName}" failed to extract NODE_NAME"
  exit 1
fi

echo "python output : ["${pyOut}"]"

# strip out the NODE_NAME value
NODE_NAME=`echo ${pyOut} | cut -d'=' -f 1 --complement`
echo "NODE_NAME="${NODE_NAME}
echo ""
echo "update UCD environment with [NODE_NAME]"
# now update the UCD environment
python processNodeName.py ${AGENT_HOME} ${UCDSERVER} ${AUTH_TOKEN} ${APPLICATION_ID} ${ENVIRONMENT_ID} ${COMPONENT_ID} ${AGENT_ID} ${NODE_NAME}
if [ $? -ne 0 ]; then
  echo "ERROR: script "${scriptName}" failed to update UCD environment with [NODE_NAME]"
  exit 1
fi

echo "-- EOF [${scriptName}] SUCCESS --"
exit 0
