#!/bin/bash
#********************************************************************************
# Licensed Materials - Property of IBM
# IBM Quick Deployer
# (c) Copyright IBM Corporation 2016. All Rights Reserved.
#
# U.S. Government Users Restricted Rights:
# Use, duplication or disclosure restricted by GSA ADP Schedule
# Contract with IBM Corp.
#
#********************************************************************************


## only checking LINUX OS version and PYTHON version


################
##  FUNCTIONS  #
################

# will check command in PATH using which
checkCommandInPath()
{
  command=$1
  echo "---checking ${command} in PATH---"
  which ${command}
  if [ $? != 0 ]
  then
    echo "${command} command not in PATH"
    rhCommandInPath="FALSE"
  else
    echo "${command} command in PATH."
    rhCommandInPath="TRUE"
  fi
  
}


###########
##  MAIN  #
###########

scriptName=$0
envProp=/etc/env.properties
. $envProp

preReqProp=./preReq.properties
. $preReqProp

# ucdRootDir=/IBMQD
# take value from envvironment
ucdRootDir=${QD_Root}


pythonFailure=FALSE
osFailure=FALSE


# check linux OS version
#########################
RHversion=`cat /etc/redhat-release`
echo "Current Red Hat Release $RHversion"
echo $RHversion | grep "Maipo"
if [ $? -eq 0 ]; then
  echo "OS is Red Hat 7"
  bRH7flag=TRUE
else
  echo $RHversion | grep "Santiago"
  if [ $? -eq 0 ]; then
    echo "OS is Red Hat 6, need to check the minor version"
    bRH6flag=TRUE
    
    RHminorVersion=`cat /etc/redhat-release | cut -d" " -f7 | cut -d"." -f2`
    RHReferencePartMinorVersion=`echo $LINUX_VERSION_MIN | cut -c3`
    
    echo "check linux version, has to be greater than or equal to [$LINUX_VERSION_MIN]"
    if [ $RHminorVersion -lt $RHReferencePartMinorVersion ]; then
      echo "ERROR: script "${scriptName}" Linux OS [$RHversion] fails test"
      osFailure=TRUE
    else
      echo "SUCCESS: linux version [$RHversion] meets requirement"s
    fi
  else
    echo "ERROR: script "${scriptName}" [$RHversion] not a supported OS [RH6 or RH7]"
    osFailure=TRUE
  fi
fi

if [ "TRUE" == $osFailure ]; then
  echo "ERROR: script "${scriptName}" One or more of the OS requirements failed"
  exit 1
else
  echo "SUCCESS: OS requirements met"
fi


# check python version
#######################
checkCommandInPath python
if [ "FALSE" == $rhCommandInPath ]; then
  echo "ERROR: script "${scriptName}" Python not found in the PATH"
  pythonFailure=TRUE
else
  # now check it is a valid version
  # btw it writes to stderr and not stdout!!
  pythonVersion=`python --version 2>&1 | cut -d" " -f2`
  # need a.b.c from the version
  # and then a crazy algorithm 
  pythonVersionPartA=`python --version 2>&1 | cut -d" " -f2 | cut -d"." -f1`
  pythonVersionPartB=`python --version 2>&1 | cut -d" " -f2 | cut -d"." -f2`
  pythonVersionPartC=`python --version 2>&1 | cut -d" " -f2 | cut -d"." -f3`
  
  pythonReferencePartA=`echo $PYTHON_VERSION_MIN | cut -c1`
  pythonReferencePartB=`echo $PYTHON_VERSION_MIN | cut -c3`
  pythonReferencePartC=`echo $PYTHON_VERSION_MIN | cut -c5`
  
  echo "check python version, has to be a [$PYTHON_VERSION_STREAM] release and greater than or equal to [$PYTHON_VERSION_MIN]"
  if [ $pythonVersionPartA -ne $pythonReferencePartA ]; then
    echo "ERROR: script "${scriptName}" Python [$pythonVersion] fails test in position 1 (wrong stream)"
    pythonFailure=TRUE
  else
    if [ $pythonVersionPartB -lt $pythonReferencePartB ]; then
      echo "ERROR: script "${scriptName}" Python [$pythonVersion] fails test in position 3"
      pythonFailure=TRUE
    elif [ $pythonVersionPartB -gt $pythonReferencePartB ]; then
      echo "SUCCESS: python version [$pythonVersion] meets requirements"
    else
      if [ $pythonVersionPartC -lt $pythonReferencePartC ]; then
        echo "ERROR: script "${scriptName}" Python [$pythonVersion] fails test in position 5"
        pythonFailure=TRUE
      else
        echo "SUCCESS: python version [$pythonVersion] meets requirements"
      fi
    fi
  fi
fi


# fail if one of the pre req checks failed
###########################################
if [ "TRUE" == $pythonFailure ] || [ "TRUE" == $osFailure ]; then
  echo "ERROR: script "${scriptName}" One or more of the basic checks failed"
  exit 1
else
  echo "-- EOF [${scriptName}] SUCCESS -- basic checks passed"
  exit 0
fi

