#!/bin/sh
#********************************************************************************
# Licensed Materials - Property of IBM
# IBM Quick Deployer
# (c) Copyright IBM Corporation 2016. All Rights Reserved.
#  
# U.S. Government Users Restricted Rights:
# Use, duplication or disclosure restricted by GSA ADP Schedule
# Contract with IBM Corp.
#
#********************************************************************************
# RULES TO IMPLEMENT
# ===================
# Must be lowercase letters (a-z), numbers (0-9), and the underscore character(_)
# Must not start with a number or underscore
# Cannot be longer than eight characters
# Cannot begin with IBM, SYS, SQL, or a number
#      Can not be USERS, ADMINS, GUESTS, PUBLIC, LOCAL

myUserName=$1
echo "username to test ["$myUserName"]"
exitCode=0
exitMessage=""
# Must be lowercase letters (a-z), numbers (0-9), and the underscore character(_)
# ========================================================================================
# [^] means match not in the range
# [!] means flip the result
#  so pass if there is only characters from the range
if ! [[ $myUserName =~ [^a-z0-9_] ]]; then
  echo "PASS: No special character found in the ID"
else
  exitMessage="$exitMessage ERROR: [Rule] - ID must only contain letters, numbers and underscore \n"
  exitCode=`expr $exitCode + 1`
fi

# <96> Must not start with a number or underscore
# ========================================================================================
tempString=`echo $myUserName | cut -c -1`
if [ $tempString != "_" ]; then
    echo "PASS: string does not start with [_]"
else
    exitMessage="$exitMessage ERROR: [Rule] - string should not starts with [_]"
    exitCode=`expr $exitCode + 1`
fi

tempString=`echo $myUserName | cut -c -1`
if [[ $tempString =~ [0-9] ]]; then
    exitMessage="$exitMessage ERROR: [Rule] - string should not starts with [number] \n"
    exitCode=`expr $exitCode + 1`
else
    echo "PASS: string does not start with [number]"
fi


# <96> Cannot be longer than eight characters
# ========================================================================================
tempString=`echo $myUserName | cut -c 1-8`
if [ $tempString == $myUserName ]; then
    echo "strings are identical --> rule passed"
else
    exitMessage="$exitMessage ERROR: [Rule] - string length can not be longer than eight characters\n"
    exitCode=`expr $exitCode + 1`
fi

# <96> Cannot begin with IBM, SYS, SQL, or a number
# ========================================================================================
tempString=`echo $myUserName | cut -c 1-3`
if [ $tempString == "IBM" ] || [ $tempString == "SYS" ] || [ $tempString == "SQL" ]; then
    exitMessage="$exitMessage ERROR: [Rule] - strings should not begins with IBM, SYS, SQL \n"
    exitCode=`expr $exitCode + 1`
fi

# Cannot have reserved keywords
if [ "$myUserName" == "users" ] || [ "$myUserName" == "admins" ] || [ "$myUserName" == "guests" ] || [ "$myUserName" == "public" ] || [ "$myUserName" == "local" ]; then
   exitMessage="$exitMessage ERROR: [Rule] - strings should not be the reserved keywords users, admins, guests, public,local \n"
   exitCode=`expr $exitCode + 1`
fi

if [ $exitCode -eq 0 ];then
   exit 0
else
   echo "ERROR: ID violate following rules:"
   echo -e "$exitMessage"
   exit $exitCode
fi
