#!/bin/sh
#********************************************************************************
# Licensed Materials - Property of IBM
# IBM Quick Deployer
# (c) Copyright IBM Corporation 2015. All Rights Reserved.
#
# U.S. Government Users Restricted Rights:
# Use, duplication or disclosure restricted by GSA ADP Schedule
# Contract with IBM Corp.
#
#********************************************************************************

. /etc/env.properties

# get credentials
userCreds=$AUTO_PREP/UserParameters/userCreds.properties
. $userCreds


if [ -e ${WAS_COMMON_DIR}/LDAP/LDAPSecurity.properties ]
then
        echo "sourcing ${WAS_COMMON_DIR}/LDAP/LDAPSecurity.properties"
        . ${WAS_COMMON_DIR}/LDAP/LDAPSecurity.properties
else
        echo "sourcing /tmp/LDAP/LDAPSecurity.properties"
        . /tmp/LDAP/LDAPSecurity.properties
fi

LOCAL_COMPONENT=$1

#DB_VENDOR=db2

echo "------Server Info------"
echo "DB vendor: " $DB_VENDOR
echo "DB2 Host Name: " $DB_HOSTNAME
echo "IHS Server FQDN: " $ihshost
echo "COMPONENT is: $LOCAL_COMPONENT"
if [ -z "$WAS_USER_NAME" ]; then
	echo "Error: WAS_USER_NAME variable did not set"
	exit 1
fi
echo "WAS_USER_NAME=$WAS_USER_NAME"


# ===== what is currently supported? =====
if [ "jts" == $LOCAL_COMPONENT ] || [ "ccm" == $LOCAL_COMPONENT ] || [ "qm" == $LOCAL_COMPONENT ] || [ "rm" == $LOCAL_COMPONENT ] || [ "rs" == $LOCAL_COMPONENT ] || [ "dcc" == $LOCAL_COMPONENT ]; then 
  echo "[$LOCAL_COMPONENT] supported"
  temp_teamserver_properties=$CONFIGURE_APP_SERVER_SCRIPTS_DIR/AppConfigScripts/temp_"$LOCAL_COMPONENT"_teamserver.properties
  JAZZ_HOME=/opt/IBM/JazzTeamServer

elif [ "dm" == $LOCAL_COMPONENT ] || [ "vvc" == $LOCAL_COMPONENT ] || [ "relm" == $LOCAL_COMPONENT ] || [ "gc" == $LOCAL_COMPONENT ]; then 
  echo "[$LOCAL_COMPONENT] supported"
  temp_teamserver_properties=$CONFIGURE_APP_SERVER_SCRIPTS_DIR/AppConfigScripts/temp_"$LOCAL_COMPONENT"_teamserver.properties
  JAZZ_HOME=/opt/IBM/JazzTeamServer
  
elif [ "lqe" == $LOCAL_COMPONENT ] || [ "ldx" == $LOCAL_COMPONENT ]; then 
  echo "[$LOCAL_COMPONENT] supported"
  temp_teamserver_properties="lqe and ldx do not have a teamserver.properties file"
  temp_dbconnection_properties=$CONFIGURE_APP_SERVER_SCRIPTS_DIR/AppConfigScripts/temp_"$LOCAL_COMPONENT"_dbconnection.properties
  JAZZ_HOME=/opt/IBM/JazzTeamServer

else
  echo "ERROR: currently do not support this component [$LOCAL_COMPONENT]"
  exit 1
fi

# lqe does not have a teamserver.properties file to update, all others do
if [ "lqe" == $LOCAL_COMPONENT ]; then 

  # ----
  timestamp=`date +%s`
  echo "DEBUG (RRT): current epoch time is ["$timestamp"] Sec"
  # ----
  echo "----- Update lqe.properties ------"
  LQE_PROPS=$JAZZ_HOME/server/conf/lqe/lqe.properties
  LQE_RELEASE_PROPS=$JAZZ_HOME/server/conf/lqe/lqe.releaseconfig.properties
  LQE_DBCONNECTION_PROPS=$JAZZ_HOME/server/conf/lqe/dbconnection.properties
  
  echo "" >> $LQE_PROPS
  echo "lqe.authtype.delegated = true" >> $LQE_PROPS
  echo "lqe.quadFilter.ignoreAccessControl = false" >> $LQE_PROPS
  echo "lqe.sparql.resultSetLimit = 1000" >> $LQE_PROPS
  n=`sed -n '/lqe.configMode *= *false/ { /#/ ! p }' $LQE_PROPS | wc -l`
  
  if [ "$n" -gt 0 ]; then
    sed -i '/lqe.configMode *= *false/ { /#/ ! {s/false/true/}}' $LQE_PROPS
  else
    echo "lqe.configMode=true" >> $LQE_PROPS
  fi
  
  echo "LQE_RELEASE_PROPS: [$LQE_RELEASE_PROPS]"
  if [ ! -f "$LQE_RELEASE_PROPS" ]; then
  	touch "$LQE_RELEASE_PROPS"
  	chmod 777 "$LQE_RELEASE_PROPS"
  fi

  
  # ----
  timestamp=`date +%s`
  echo "DEBUG (RRT): current epoch time is ["$timestamp"] Sec"
  # ----
  echo "lqe.properties - updated"

fi

echo "temp teamserver.properties [$temp_teamserver_properties]"
echo "JAZZ_HOME is: $JAZZ_HOME"



# ----
timestamp=`date +%s`
echo "DEBUG (RRT): current epoch time is ["$timestamp"] Sec"
# ----
# ===== copy the desired template =====
# -- using the common template
if [ "jts" == $LOCAL_COMPONENT ] || [ "qm" == $LOCAL_COMPONENT ]; then
  cp -f $CONFIGURE_APP_SERVER_SCRIPTS_DIR/AppConfigScripts/template_teamserver.properties $temp_teamserver_properties
fi
if [ "rs" == $LOCAL_COMPONENT ]; then
  cp -f $CONFIGURE_APP_SERVER_SCRIPTS_DIR/AppConfigScripts/template_teamserver.properties $temp_teamserver_properties
fi

# -- using the app specific template
if [ "rm" == $LOCAL_COMPONENT ] || [ "ccm" == $LOCAL_COMPONENT ]; then
  cp -f $CONFIGURE_APP_SERVER_SCRIPTS_DIR/AppConfigScripts/"$LOCAL_COMPONENT"_template_teamserver.properties $temp_teamserver_properties
fi
if [ "dm" == $LOCAL_COMPONENT ] || [ "vvc" == $LOCAL_COMPONENT ] || [ "relm" == $LOCAL_COMPONENT ] || [ "gc" == $LOCAL_COMPONENT ] || [ "dcc" == $LOCAL_COMPONENT ]; then 
  cp -f $CONFIGURE_APP_SERVER_SCRIPTS_DIR/AppConfigScripts/"$LOCAL_COMPONENT"_template_teamserver.properties $temp_teamserver_properties
fi

# -- not using teamserver.properties
if [ "lqe" == $LOCAL_COMPONENT ] || [ "ldx" == $LOCAL_COMPONENT ]; then
  cp -f $CONFIGURE_APP_SERVER_SCRIPTS_DIR/AppConfigScripts/lqe_template_dbconnection.properties $temp_dbconnection_properties
fi

# ===== update the templates =====
if [ $EnableCM == TRUE ];then
   if [ "qm" == $LOCAL_COMPONENT ] || [ "rm" == $LOCAL_COMPONENT ] || [ "dm" == $LOCAL_COMPONENT ];
   then
      echo "---------- Add activation key ------------"
      echo "">> $temp_teamserver_properties 
      echo "com.ibm.team.repository.vvc.activationKey=$CMActivationKey" >> $temp_teamserver_properties
   fi
fi

if [ $EnableNTPclock == TRUE ];then
   if [ "jts" == $LOCAL_COMPONENT ] || [ "ccm" == $LOCAL_COMPONENT ] || [ "qm" == $LOCAL_COMPONENT ] || [ "rm" == $LOCAL_COMPONENT ] || [ "dm" == $LOCAL_COMPONENT ] || [ "vvc" == $LOCAL_COMPONENT ] || [ "relm" == $LOCAL_COMPONENT ] || [ "gc" == $LOCAL_COMPONENT ] || [ "dcc" == $LOCAL_COMPONENT ]; then 
      echo "---------- Add NTP clock entry ------------"
      echo "">> $temp_teamserver_properties 
      echo "com.ibm.team.repository.diagnostic.systemClockDiagnostic.ntpServerAddress=$NTPclock" >> $temp_teamserver_properties
      
   fi
fi

echo "------------ Update the properties files -------------"

if [ "lqe" != $LOCAL_COMPONENT ] && [ "ldx" != $LOCAL_COMPONENT ];
then
   echo "server host names"
   sed -i s%_MOD_DB_HOSTNAME_%$DB_HOSTNAME% $temp_teamserver_properties
   sed -i s%_WEB_SERVER_HOSTNAME_%$ihshost% $temp_teamserver_properties
fi
if [ "jts" == $LOCAL_COMPONENT ] || [ "ccm" == $LOCAL_COMPONENT ] || [ "qm" == $LOCAL_COMPONENT ] || [ "rm" == $LOCAL_COMPONENT ] || [ "dcc" == $LOCAL_COMPONENT ] || [ "gc" == $LOCAL_COMPONENT ]; then
  sed -i s%_DW_DB_HOSTNAME_%$DB_HOSTNAME% $temp_teamserver_properties
fi


if [ "jts" == $LOCAL_COMPONENT ] || [ "ccm" == $LOCAL_COMPONENT ] || [ "qm" == $LOCAL_COMPONENT ] || [ "dcc" == $LOCAL_COMPONENT ] || [ "rs" == $LOCAL_COMPONENT ]; then
  echo "LDAP properties"
  echo "jazz_ldap_baseGroupDN is ["$jazz_ldap_baseGroupDN"]"
  sed -i s%BASE_GROUP_DN%$jazz_ldap_baseGroupDN% $temp_teamserver_properties
  sed -i s%BASE_USER_DN%$jazz_ldap_baseUserDN% $temp_teamserver_properties
  sed -i s%REGISTRY_LOCATION%'ldap://'$jazz_userrealm% $temp_teamserver_properties
  sed -i s%REGISTRY_USERNAME%$jazz_userrole_RegistryUsername% $temp_teamserver_properties
  sed -i s%REGISTRY_PASSWORD%$jazz_userrole_RegistryPassword% $temp_teamserver_properties
  sed -i s%GROUP_MAPPING%$jazz_ldap_groupMapping% $temp_teamserver_properties
  sed -i s%MEMBERS_OF_GROUP%$jazz_ldap_membersOfGroup% $temp_teamserver_properties
  sed -i s%FIND_GROUPS_QUERY%$jazz_ldap_findGroupsForUserQuery% $temp_teamserver_properties
  sed -i s%USER_ATTRIBUTE_MAPPING%$jazz_ldap_userAttributesMapping% $temp_teamserver_properties

  echo "jazz_ldap_vendor is ["$jazz_ldap_vendor"]"  
  if [ "MSAD" == $jazz_ldap_vendor ]; then
    sed -i s%_FIND_USER_QUERY_PROP_NAME_%findUsersByUserIdQuery% $temp_teamserver_properties
  else
    sed -i s%_FIND_USER_QUERY_PROP_NAME_%findGroupsForUserQuery% $temp_teamserver_properties
  fi

fi

if [ "lqe" == $LOCAL_COMPONENT ] || [ "ldx" == $LOCAL_COMPONENT ]; then
  sed -i s%_MOD_DB_HOSTNAME_%$DB_HOSTNAME% $temp_dbconnection_properties
fi 

if [ "lqe" != $LOCAL_COMPONENT ] && [ "ldx" != $LOCAL_COMPONENT ]; then
  echo "disable cluster"
  echo " " >> $temp_teamserver_properties
  echo "com.ibm.team.repository.cluster.isInCluster=false" >>  $temp_teamserver_properties
fi


if [ "db2" == $DB_VENDOR ]; then
  if [ "lqe" == $LOCAL_COMPONENT ] || [ "ldx" == $LOCAL_COMPONENT ]; then
     sh $CONFIGURE_APP_SERVER_SCRIPTS_DIR/AppConfigScripts/Repotool_DB2_updates.sh $temp_dbconnection_properties $LOCAL_COMPONENT
  else
     sh $CONFIGURE_APP_SERVER_SCRIPTS_DIR/AppConfigScripts/Repotool_DB2_updates.sh $temp_teamserver_properties $LOCAL_COMPONENT
  fi
elif [ "oracle" == $DB_VENDOR ]; then
  echo "copy oracle driver to the node"
  sh $AUTO_PREP/MediaParameters/doWget.sh $MEDIA_SERVER/Oracle/ojdbc6.jar
  mkdir $JAZZ_HOME/server/oracle
  mv -f ojdbc6.jar $JAZZ_HOME/server/oracle/ojdbc6.jar
  if [ "lqe" == $LOCAL_COMPONENT ] || [ "ldx" == $LOCAL_COMPONENT ]; then
     sh $CONFIGURE_APP_SERVER_SCRIPTS_DIR/AppConfigScripts/Repotool_oracle_updates.sh $temp_dbconnection_properties $LOCAL_COMPONENT
  else
     sh $CONFIGURE_APP_SERVER_SCRIPTS_DIR/AppConfigScripts/Repotool_oracle_updates.sh $temp_teamserver_properties $LOCAL_COMPONENT
  fi
elif [ "sql" == $DB_VENDOR ]; then
  echo "currently ["$DB_VENDOR"] is not supported"
  exit 1
else
  echo "ERROR: database ["$DB_VENDOR"] is not supported"
  exit 1
fi

# ----
timestamp=`date +%s`
echo "DEBUG (RRT): current epoch time is ["$timestamp"] Sec"
# ----
echo "------------ Updates complete -------------"


# ===== copy the modified template to its real location =====
if [ "lqe" == $LOCAL_COMPONENT ] || [ "ldx" == $LOCAL_COMPONENT ]; then
   # it is actually file creation not replacement
   echo "---- copy dbconnection.properties file to ${JAZZ_HOME}/server/conf/${LOCAL_COMPONENT} ----"
   JAZZ_HOME=$JAZZ_HOME su $WAS_USER_NAME -c "cp -f $temp_dbconnection_properties $JAZZ_HOME/server/conf/$LOCAL_COMPONENT/dbconnection.properties"
   if [ $? -ne 0 ]
   then
     echo "Failed to copy dbconnection.properties file"
     exit 1
   fi
else
   if [ "rs" != $LOCAL_COMPONENT ]; then
     echo "------Copy teamserver.properties file originally installed------"
     # it is actually file replacement, so make a copy first
     JAZZ_HOME=$JAZZ_HOME su $WAS_USER_NAME -c "cp -f $JAZZ_HOME/server/conf/$LOCAL_COMPONENT/teamserver.properties $JAZZ_HOME/server/conf/$LOCAL_COMPONENT/teamserver-orig.properties"
     if [ $? -ne 0 ]
     then
       echo "Failed to copy teamserver.properties files to teamserver-orig.properties in ${JAZZ_HOME}/server/conf/${LOCAL_COMPONENT}"
       exit 1
     fi
   fi
   echo "------Copy teamserver.properties files to ${JAZZ_HOME}/server/conf/${LOCAL_COMPONENT}------"
   JAZZ_HOME=$JAZZ_HOME su $WAS_USER_NAME -c "cp -f $temp_teamserver_properties $JAZZ_HOME/server/conf/$LOCAL_COMPONENT/teamserver.properties"
   if [ $? -ne 0 ]
   then
     echo "Failed to copy teamserver.properties file"
     exit 1
   fi
fi

if [ "lqe" = $LOCAL_COMPONENT ] || [ "ldx" = $LOCAL_COMPONENT ]; then
   ls -l "$JAZZ_HOME/server/conf/$LOCAL_COMPONENT/dbconnection.properties"
   echo "-----------------------"
   echo " "
else
   ls -l "$JAZZ_HOME/server/conf/$LOCAL_COMPONENT/teamserver.properties"
   echo "-----------------------"
   echo " "
fi

# ===== run repotools command =====

if [ "$LOCAL_COMPONENT" = "rs" ] || [ "$LOCAL_COMPONENT" = "lqe" ] || [ "ldx" = $LOCAL_COMPONENT ] ; then
    # -- rs is not expected to need repotools
    echo "------------- [$LOCAL_COMPONENT] Skip repo tool execution ------------"
else
  
    # ----
    timestamp=`date +%s`
    echo "DEBUG (RRT): current epoch time is ["$timestamp"] Sec"
    # ----
    echo "------Run Repo Tools for $LOCAL_COMPONENT Tables------"
    JAZZ_HOME=$JAZZ_HOME LOCAL_COMPONENT=$LOCAL_COMPONENT su $WAS_USER_NAME -c 'cd $JAZZ_HOME/server;./repotools-$LOCAL_COMPONENT.sh -createTables teamserver.properties="$JAZZ_HOME/server/conf/$LOCAL_COMPONENT/teamserver.properties" logFile=repotools_$LOCAL_COMPONENT.log'
    if [ $? -ne 0 ]; then
      echo "Repo Tools Failed to Create $LOCAL_COMPONENT Tables"
      exit 1
    fi
    
    timestampDone=`date +%s`
    timeTaken=`expr $timestampDone - $timestamp`
    echo "DEBUG (RRT): Repo Tools for $LOCAL_COMPONENT Tables took ["$timeTaken"] Sec"
    
    echo "-----------------------"
    echo " "
fi
  

# ----
timestamp=`date +%s`
echo "DEBUG (RRT): current epoch time is ["$timestamp"] Sec"
# ----


# ===== create jts datawarehouse =====
# note: this also appears to create the DCC DW tables
if [ "$LOCAL_COMPONENT" = "jts" ]; then
  #Create DW Tables
  # ----
  timestamp=`date +%s`
  echo "DEBUG (RRT): current epoch time is ["$timestamp"] Sec"
  # ----

  echo "------Run Repo Tools for Data WareHouse Tables------"
  JAZZ_HOME=$JAZZ_HOME su $WAS_USER_NAME -c 'cd $JAZZ_HOME/server;./repotools-jts.sh -createWarehouse teamserver.properties="$JAZZ_HOME/server/conf/jts/teamserver.properties" logFile=repotools_dw.log'
  if [ $? -ne 0 ]; then
    echo "Repo Tools Failed to Create Data WareHouse Tables"
    exit 1
  fi
  
  timestampDone=`date +%s`
  timeTaken=`expr $timestampDone - $timestamp`
  echo "DEBUG (RRT): Repo Tools for $LOCAL_COMPONENT Data WareHouse Tables took ["$timeTaken"] Sec"
  
  echo "-----------------------"
  echo " "
fi

# ----
timestamp=`date +%s`
echo "DEBUG (RRT): current epoch time is ["$timestamp"] Sec"
# ----
echo "Repo Tools - Table creation successful"
exit 0

