#!/bin/sh
#********************************************************************************
# Licensed Materials - Property of IBM
# IBM Quick Deployer
# (c) Copyright IBM Corporation 2015. All Rights Reserved.
#
# U.S. Government Users Restricted Rights:
# Use, duplication or disclosure restricted by GSA ADP Schedule
# Contract with IBM Corp.
#
#********************************************************************************

envProp=/etc/env.properties
touch $envProp
. $envProp


# from the environment
WAS_HOME=$WAS_PROFILE_ROOT
WAS_SCRIPTS_DIR=${WAS_COMMON_DIR}/WASScripts

export ihshost=$1
export DB_HOSTNAME=$2
export DB_VENDOR=$3
echo DB_HOSTNAME=$DB_HOSTNAME>> $envProp
echo DB_VENDOR=$DB_VENDOR>> $envProp

CurrentWorkPath=`pwd -P`
echo "CurrentWorkPath: [$CurrentWorkPath]"
echo CONFIGURE_APP_SERVER_SCRIPTS_DIR=$CurrentWorkPath>> $envProp
export CONFIGURE_APP_SERVER_SCRIPTS_DIR=$CurrentWorkPath
. ./script.properties
cat ./script.properties>> $envProp

# ----
timeStart=`date +%s`
timestamp=`date +%s`
echo "DEBUG (CAS): current epoch time is ["$timestamp"] Sec"
# ----
echo "------------------------- Stop WAS --------------------"
# actual schell script will be run as nonRoot user
if [ ! -d "$WAS_SCRIPTS_DIR" ]; then
echo "This pattern is missing WASCommon. Exiting."
exit 1
fi
sh $WAS_SCRIPTS_DIR/StopSingleWAS.sh
if [ $? -ne 0 ]
then
echo "WebSphere Server failed to stop"
#exit 1
fi

timestampDone=`date +%s`
timeTaken=`expr $timestampDone - $timestamp`
echo "DEBUG (CAS): WebSphere Server (Stop) took ["$timeTaken"] Sec"

echo "WebSphere Server stopped"
# ----
timestamp=`date +%s`
echo "DEBUG (CAS): current epoch time is ["$timestamp"] Sec"
# ----

echo "----------------------- select apps for repo tool command -------------------"
#Getting the application list from environment variable "APPS" in /etc/env.properties
apps=$APPS
apps=${apps//,/ }
echo "apps ($apps)"

for a in $apps
do
	# ----
	timestamp=`date +%s`
	echo "DEBUG (CAS): current epoch time is ["$timestamp"] Sec"
	# ----
	echo "----------------------- Run repo tool [${a}] commands -------------------"
	# actual shell script will be run as nonRoot user
	sh $CONFIGURE_APP_SERVER_SCRIPTS_DIR/AppConfigScripts/RunRepotool.sh ${a}
	if [ $? -ne 0 ]
	then
		echo "RunRepotools failed to create tables"
		exit 1
	fi
	echo "RunRepotools created tables"
done 

# ----
timestamp=`date +%s`
echo "DEBUG (CAS): current epoch time is ["$timestamp"] Sec"
# ----
echo "--------------------- restart WAS -----------"
# actual schell script will be run as nonRoot user
sh $WAS_SCRIPTS_DIR/StartSingleWAS.sh
if [ $? -ne 0 ]; then
  echo "WebSphere Server failed to start"
  exit 1
fi

timestampDone=`date +%s`
timeTaken=`expr $timestampDone - $timestamp`
echo "DEBUG (CAS): WebSphere Server (Start) took ["$timeTaken"] Sec"

echo "WebSphere Server started"

# ----
timestamp=`date +%s`
echo "DEBUG (CAS): current epoch time is ["$timestamp"] Sec"
# ----
echo "------------------------- Install Application to WAS -----------------"
# actual schell script will be run as nonRoot user

cd $CONFIGURE_APP_SERVER_SCRIPTS_DIR
sh $CONFIGURE_APP_SERVER_SCRIPTS_DIR/InstallApp.sh
if [ $? -ne 0 ]
then
echo "ERROR: Application failed to install to WAS"
exit 1
fi
echo "Application installed to WAS"

# ----
timestamp=`date +%s`
echo "DEBUG (CAS): current epoch time is ["$timestamp"] Sec"
# ----
echo "pause 60 seconds to wait for all applications to start..."
sleep 60

# ----
timestamp=`date +%s`
echo "DEBUG (CAS): current epoch time is ["$timestamp"] Sec"
# ----

timeEnd=`date +%s`
timeTaken=`expr $timeEnd - $timeStart`
echo "DEBUG (CAS): configAppServer.sh took ["$timeTaken"] Sec"

echo "--------------------- end of script  -----------"
