#!/bin/sh
#********************************************************************************
# Licensed Materials - Property of IBM
# IBM Quick Deployer
# (c) Copyright IBM Corporation 2015. All Rights Reserved.
#
# U.S. Government Users Restricted Rights:
# Use, duplication or disclosure restricted by GSA ADP Schedule
# Contract with IBM Corp.
#
#********************************************************************************
. /etc/env.properties

envProp=/etc/env.properties
. $envProp

# get credentials
userCreds=$AUTO_PREP/UserParameters/userCreds.properties
. $userCreds

echo "WASCOMMON=$WAS_COMMON_DIR"
echo "WAS_PROFILE_ROOT=$WAS_PROFILE_ROOT"
echo "WAS_USER_NAME=$WAS_USER_NAME"

# Xvfb is a system requirement
echo "---Require Xvfb on port :3---"
if ps -ef | grep -v "grep" | grep "Xvfb.*:3 "
then
  echo "Xvfb [:3] already running"
else
  echo "starting Xvfb [:3]"
  Xvfb :3 -screen 0 800x600x24 >&- 2>&- & 
  sleep 10
  
  if ps -ef | grep -v "grep" | grep "Xvfb.*:3 "
  then
    echo "Xvfb [:3] running"
  else
    echo "ERROR: Xvfb [:3] not running!"
    exit 1
  fi
fi


echo "---Setting DISPLAY---"
DISPLAY=:3.0
export DISPLAY

echo "---Adding DISPLAY to startNode.sh---"
sed -i "s%Bootstrap values ...%ADDED FOR CONVERTER CLUSTERING SUPPORT\nDISPLAY=:3.0\nexport DISPLAY\n\n# Bootstrap values ...%" /opt/IBM/WebSphere/AppServer/bin/start*.sh

# setting up automatically start up script for Xvfb
cp ${WAS_COMMON_DIR}/Xvfb_start /etc/init.d
chmod o+x /etc/init.d/Xvfb_start
chkconfig --add Xvfb_start
echo "checking start up scripts"
ls -l /etc/init.d/Xvfb_start

echo "----- Modify the JVM properties based on RAM size"
${WAS_COMMON_DIR}/SetCorrectHeapSize.sh
if [ $? -ne 0 ]; then
	echo "Heapsize not set in was.properties. Exiting"
	exit 1
fi
echo "----- SetJvmProps"
su - $OSUserName -c "$WAS_PROFILE_ROOT/bin/wsadmin.sh -lang jython -f ${WAS_COMMON_DIR}/SetJvmProps.jy $WAS_COMMON_DIR" 
if [ $? -ne 0 ]
	then
	echo "WAS JVM settings NOT updated"
	exit 1
fi

echo "------ SetWebContainerThreadPool"
su - $OSUserName -c "$WAS_PROFILE_ROOT/bin/wsadmin.sh -lang jython -f ${WAS_COMMON_DIR}/SetThreadPoolProps.jy $WAS_COMMON_DIR" 
if [ $? -ne 0 ]
	then
	echo "WAS Webcontainer Threadpool settings NOT updated"
	exit 1
fi

echo "----- Update WAS Session Management settings"
su - $OSUserName -c "$WAS_PROFILE_ROOT/bin/wsadmin.sh -lang jython -f ${WAS_COMMON_DIR}/SetSMProps.jy $WAS_COMMON_DIR"
if [ $? -ne 0 ]
	then
	echo "WAS Session Management settings NOT updated"
	exit 1
fi
echo " "

echo $APPS |grep jts
if [ $? == 0 ]
then
   sh ${WAS_COMMON_DIR}/EnableSSO.sh export
   if [ $? -ne 0 ]
        then
        echo "JTS Single Sign on doesn't enabled"
        exit 1
   fi
fi
echo " "

echo "----- Start WAS After WAS Config"
${WAS_COMMON_DIR}/WASScripts/RestartSingleWAS.sh

echo "----- WAS settings updated"
exit 0
