#!/bin/sh
#********************************************************************************
# Licensed Materials - Property of IBM
# IBM Quick Deployer
# (c) Copyright IBM Corporation 2015. All Rights Reserved.
#
# U.S. Government Users Restricted Rights:
# Use, duplication or disclosure restricted by GSA ADP Schedule
# Contract with IBM Corp.
#
#********************************************************************************
. /etc/env.properties

# get credentials
userCreds=$AUTO_PREP/UserParameters/userCreds.properties
. $userCreds

# Get WAS ADMIN PASSWORD
# ======================================
tempPassword=`echo ${WAS_PASSWORD} | base64 -d`

WASScripts=${WAS_COMMON_DIR}/WASScripts
LDAPScripts=${WAS_COMMON_DIR}/LDAP

echo "WAS_USER_NAME=$WAS_USER_NAME"
echo "WAS_PROFILE_ROOT=$WAS_PROFILE_ROOT"
echo "LDAPPROP=$LDAPPROP"

echo "----- Set appropriate LDAP script according to env"
if [ "$LDAPPROP" ]; then
  mkdir -p $LDAPScripts
  if [ "$LDAPPROP" == "CustomLDAP" ]; then
    if [ -e "$AUTO_PREP/CustomLDAP/Custom_LDAPSecurity.properties" ]; then
      cp -f $AUTO_PREP/CustomLDAP/Custom_LDAPSecurity.properties $LDAPScripts/${LDAPPROP}_LDAPSecurity.properties
    else
      echo "ERROR: [$AUTO_PREP/CustomLDAP/Custom_LDAPSecurity.properties] not found"
      exit 1
    fi
  fi
  if [ -e "$LDAPScripts/${LDAPPROP}_LDAPSecurity.properties" ]; then
    echo "----- Substituting LDAPSecurity.properties for $LDAPPROP"
    cp -f $LDAPScripts/${LDAPPROP}_LDAPSecurity.properties $LDAPScripts/LDAPSecurity.properties
    sed -i s/_LDAP_ADMIN_USER_/$WAS_USER_NAME/ $LDAPScripts/LDAPSecurity.properties
    sed -i s/_LDAP_ADMIN_PASSWORD_/$WAS_PASSWORD/ $LDAPScripts/LDAPSecurity.properties
  else
    echo "ERROR: [${LDAPPROP}_LDAPSecurity.properties] not found"
    exit 1
  fi
fi

. $LDAPScripts/LDAPSecurity.properties
echo "jazz_ldap_primaryid=$jazz_ldap_primaryid"

echo "----- enable LDAP and sync nodes ---------------------------"

# double quote so WAS_PROFILE_ROOT will be interpreted from root's env
su -c "$WAS_PROFILE_ROOT/bin/wsadmin.sh -lang jython -f ${WAS_COMMON_DIR}/enableLDAP.jy $LDAPPROP $WAS_COMMON_DIR" - $OSUserName
if [ $? -ne 0 ]; then
echo "Could not set LDAP for $LDAPPROP. Login to the WAS console, disable administrative security, restart the server, then run this script again."
exit 1
fi

# Set the credentials so WAS_USER_NAME can start/stop WAS

# Note if WAS_USER_NAME is different than the owner of WAS/bin files,
# Then they need to set credentials to be able to execute wsadmin
# in their java user.home directory which overrides soap.client.props
# SOAPPROPS=~${WAS_USER_NAME}/wsadmin.properties

# If manually adding passwords in soap.client.props, then encrypt password with
# $WAS_PROFILE_ROOT/bin/PropFilePasswordEncoder.sh $SOAPPROPS com.ibm.SOAP.loginPassword
echo "----- Setting up soap properties for $jazz_ldap_primaryid"
SOAPPROPS="$WAS_PROFILE_ROOT/properties/soap.client.props"
echo "SOAPPROPS=$SOAPPROPS"
if [ -e $SOAPPROPS ]; then
	sed -i s/^.*com.ibm.SOAP.securityEnabled=.*$/com.ibm.SOAP.securityEnabled=true/ $SOAPPROPS
	sed -i s/^.*com.ibm.SOAP.loginUserid=.*$/com.ibm.SOAP.loginUserid=$jazz_ldap_primaryid/ $SOAPPROPS
	sed -i s/^.*com.ibm.SOAP.loginPassword=.*$/com.ibm.SOAP.loginPassword=$tempPassword/ $SOAPPROPS
else
	echo com.ibm.SOAP.securityEnabled=true > $SOAPPROPS
	echo com.ibm.SOAP.loginUserid=$jazz_ldap_primaryid >> $SOAPPROPS
	echo com.ibm.SOAP.loginPassword=$tempPassword >> $SOAPPROPS
fi
$WAS_PROFILE_ROOT/bin/PropFilePasswordEncoder.sh $SOAPPROPS com.ibm.SOAP.loginPassword


echo "----- Stopping WAS After LDAP enabled --------------------------------"

$WASScripts/StopSingleWAS.sh
if [ $? -ne 0 ]; then
	echo "Server didn't stop. Try restarting using the old admin's credentials for the stopServer action only. "
	#Try to avoid use the username and password
	if [ -f $WAS_PROFILE_ROOT/logs/server1/server1.pid ]; then	
		WAS_pid=`cat $WAS_PROFILE_ROOT/logs/server1/server1.pid`
		echo "WAS_pid: [$WAS_pid]"
		echo "Kill the WAS process since the authentication is changed"
		kill -9 $WAS_pid
        if [ $? -ne 0 ]; then
            echo "Error: Second attempt to stop server failed, please investigate the issue"
            exit 1
        fi
	else
		echo "Error: Do not how to stop the WAS process, the PID do not exist, it maybe stopped or some other reason"
		exit 1
	fi
fi

echo "-----Start WAS After LDAP enabled --------------------------------"
$WASScripts/StartSingleWAS.sh
echo $?
if [ $? -ne 0 ]; then
   echo "Error: Server didn't start normally." 
   exit 1
fi
exit 0	