#!/bin/bash

#********************************************************************************
# Licensed Materials - Property of IBM
# IBM Quick Deployer
# (c) Copyright IBM Corporation 2015. All Rights Reserved.
#  
# U.S. Government Users Restricted Rights:
# Use, duplication or disclosure restricted by GSA ADP Schedule
# Contract with IBM Corp.
#
#********************************************************************************

#############
## FUNCTIONS 
#############


exitWithErrMsg()
{
  tempString=$1
  echo "-- ERROR [${scriptName}] --"
  echo "-- message: $tempString"
  exit 1
}


## usage checkFileExists tempFile
checkFileExists()
{
  tempFile=$1
  if [ -f $tempFile ]; then
    echo "file [$tempFile] located"
  else
    echo "ERROR: [$tempFile] does not exist"
    exit 1
  fi
}


downloadHttpZip()
{
  fileUrl=$1
  filename=$(basename $fileUrl)

  sh $AUTO_PREP/MediaParameters/doWget.sh $fileUrl
  if [ $? == 0 ]
  then
    echo "download complete"
    checkFileExists $filename
  else
    errMsg="failed to download file ["${filename}"]"
    exitWithErrMsg "$errMsg"
  fi
}

copyZip()
{
  file=$1
  filename=$(basename $file)
  echo "copy ["${file}"] to ["${filename}"]"
  cp $file $filename
  if [ $? == 0 ]
  then
    echo "copy complete" 
    checkFileExists $filename
  else
    errMsg="failed to copy file ["${filename}"]"
    exitWithErrMsg "$errMsg"
  fi
}


unzipZip()
{
  zipFile=$1
  targetDir=$2
  
  unzip ${zipFile} -d ${targetDir}
  if [ $? == 0 ]; then
    echo "unzip successful" 
  else
    errMsg="failed to unzip  ["${zipFile}"]"
    exitWithErrMsg "$errMsg"
  fi
}


####################
##                ##
## ==== MAIN ==== ##
##                ##
####################

timestamp=`date +%s`
echo "DEBUG (start) : current epoch time is ["$timestamp"] Sec"

## ==== expectations from other files / scripts ====
## will use SED for substitution
## will use cut for substring extraction

## env.properties to contain this I think

## assume we run from the script's directory containing
##  installApp.sh, testulimit.sh, generic_template.xml

scriptName=$0
workingDir=`pwd -P`

# get env properties
envProp=/etc/env.properties
. $envProp

# get media properties
mediaProp=$AUTO_PREP/MediaParameters/media.properties
. $mediaProp

keyringfileloc=/tmp/IM_Keyring
## IM_templateFile=generic_template.xml
IMXML=$workingDir/IMresponses.xml
CLM_HOME=/opt/IBM/JazzTeamServer
CLM_CACHE=/opt/IBM/IBMIMShared


## ======================================================================
## ==== IM command params, not supporting use of keyring file
IMsecureStorageFile=$keyringfileloc/IM.Cred
IMpasswordFile=$keyringfileloc/password.txt
IM_LOCATION=/opt/IBM/InstallationManager/eclipse


## ======================================================================
## ==== Set correct ulimit ====
## workingDir=`pwd -P`
chmod -R 777 $workingDir
echo "Set correct ulimit"
chmod +rwx $workingDir/testulimit.sh
cd $workingDir
./testulimit.sh


## ======================================================================
## ==== input parameters come from media.properties or the GUI via env.properties ====
## -- $APPS
## -- $appMediaType
SUPPORTED_COMPONENT="{jts/ccm/qm/rm/dm/vvc/relm/lqe/rs/dcc clm/sse}"
INSTALLED_COMPONENTS=""

if [ "XX" == "X"${appMediaType}"X" ]; then
  errMsg="$!appMediaType [$appMediaType] not set!"
  exitWithErrMsg "$errMsg"
fi
if [ "XX" == "X"${mediaAccess}"X" ]; then
  errMsg="$!mediaAccess [$mediaAccess] not set!"
  exitWithErrMsg "$errMsg"
fi

if [ "XX" == "X"${appMediaRoot}"X" ]; then
  errMsg="$!appMediaRoot [$appMediaRoot] not set!"
  exitWithErrMsg "$errMsg"
fi

if [ "HTTP" == $mediaAccess ] || [ "HTTPS" == $mediaAccess ] || [ "FILE" == $mediaAccess ]; then
  echo "using [${mediaAccess}] for media access type"
else
  errMsg="["${mediaAccess}"] media access type not supported"
  exitWithErrMsg "$errMsg"
fi


if [ "SSE" == $appMediaType ] || [ "CE" == $appMediaType ] || [ "CLM" == $appMediaType ] || [ "ZIP" == $appMediaType ] || [ "FILE" == $appMediaType ]; then 
  echo "using [${appMediaType}] media location type"
  
  if [ "SSE" == $appMediaType ] || [ "CE" == $appMediaType ] || [ "CLM" == $appMediaType ]; then
    appMediaContent=$appMediaType
  fi
  
  if [ "ZIP" == $appMediaType ]; then
    if [ "HTTP" == $mediaAccess ] || [ "HTTPS" == $mediaAccess ]; then
      echo "$!appMediaContent supplied by media.properties"
    else
      if [ "XX" == "X"${appMediaRoot}"X" ]; then
        errMsg="$!appMediaRoot [$appMediaRoot] not set!"
        exitWithErrMsg "$errMsg"
      else
        appMediaContent=`echo ${appMediaRoot} | cut -c -2`
        if [ "SS" == $appMediaContent ]; then
          appMediaContent="SSE"
        elif  [ "CL" == $appMediaContent ]; then
          appMediaContent="CLM"
        elif  [ "CE" == $appMediaContent ]; then
          # only here for documentation purposes!
          appMediaContent="CE"
        else
          appMediaContent=$appMediaContent
        fi
      fi
    fi
  fi
  
  if [ "FILE" == $appMediaType ]; then
    if [ "XX" == "X"${appMediaRoot}"X" ]; then
      errMsg="$!appMediaRoot [$appMediaRoot] not set!"
      exitWithErrMsg "$errMsg"
    else
      appMediaContent=`echo ${appMediaRoot} | cut -c -2`
      if [ "SS" == $appMediaContent ]; then
        appMediaContent="SSE"
      elif  [ "CL" == $appMediaContent ]; then
        appMediaContent="CLM"
      elif  [ "CE" == $appMediaContent ]; then
        # only here for documentation purposes!
        appMediaContent="CE"
      else
        appMediaContent=$appMediaContent
      fi
    fi
  fi
  
else
  errMsg="["${appMediaType}"] media location type not supported"
  exitWithErrMsg "$errMsg"
fi


if [ "XX" == "X"${appMediaContent}"X" ]; then
  errMsg="$!appMediaContent [$appMediaContent] not set!"
  exitWithErrMsg "$errMsg"
fi
if [ "SSE" == $appMediaContent ] || [ "CE" == $appMediaContent ] || [ "CLM" == $appMediaContent ]; then
  echo "using [${appMediaContent}] media content"
else
  errMsg="["${appMediaContent}"] media content not supported"
  exitWithErrMsg "$errMsg"
fi


# already know appMediaContent, now set the IM XML response file name
if [ "SSE" == $appMediaContent ]; then
  appRelease=`echo ${appMediaRoot} | cut -c 4-`
elif  [ "CLM" == $appMediaContent ]; then
  appRelease=`echo ${appMediaRoot} | cut -c 4-`
elif  [ "CE" == $appMediaContent ]; then
  appRelease=`echo ${appMediaRoot} | cut -c 3-`
else
  # does not matter as $appMediaContent will fail when tested later
  appRelease=601
fi
echo "appMediaRoot [${appMediaRoot}], appRelease [${appRelease}]"

# so now have $appRelease = one of {60,600,601,602,etc}
if [ $appRelease -lt 601 ]; then
  # pre liberty
  IM_templateFile=generic_template600.xml
else
  # liberty supported
#  IM_templateFile=generic_template601.xml
  IM_templateFile=generic_template${appRelease}.xml
fi
echo "using [${IM_templateFile}] as the IM response file"
checkFileExists ${IM_templateFile}

if [ "X"$nfsEnabled"X" == "XX" ]; then
  echo "no NFS drive exists, assuming any ZIP files are local"
  nfsEnabled=FALSE
else
  # need to check value
  if [ "FALSE" == $nfsEnabled ]; then
    echo "no NFS drive exists, assuming any ZIP files are local"
    nfsEnabled=FALSE
  elif [ "TRUE" == $nfsEnabled ]; then 
    echo "NFS drive exists, assuming any ZIP files are remote"
  else
    errMsg="["${nfsEnabled}"] nfsEnabled not supported"
    exitWithErrMsg "$errMsg"
  fi
fi


if [ "X"$createMediaOnly"X" == "XX" ]; then
  echo "installing applications"
  createMediaOnly=FALSE
else
  # need to check value
  if [ "FALSE" == $createMediaOnly ]; then
    echo "installing applications"
    createMediaOnly=FALSE
  elif [ "TRUE" == $createMediaOnly ]; then 
    echo "adding application installer to media server"
  else
    errMsg="["${createMediaOnly}"] createMediaOnlyFlag not supported"
    exitWithErrMsg "$errMsg"
  fi
fi


if [ "X"$debugDoNotInstall"X" == "XX" ]; then
  echo "installing applications"
  debugDoNotInstall=FALSE
else
  # need to check value
  if [ "FALSE" == $debugDoNotInstall ]; then
    echo "installing applications"
    debugDoNotInstall=FALSE
  elif [ "TRUE" == $debugDoNotInstall ]; then
    echo "DEBUG: will exit prior to installing applications"
  else
    errMsg="["${debugDoNotInstall}"] debugDoNotInstallFlag not supported"
    exitWithErrMsg "$errMsg"
  fi
fi


## ======================================================================
## set $RepoLoc location
unzipFolderNeedsDeleted=FALSE
zipNeedsDeleted=FALSE
if [ "SSE" == $appMediaType ] || [ "CE" == $appMediaType ]; then
  ## using SSE repo
  if [ "X"$SSE_BUILD_ID"X" == "XX" ] || [ "X"$SSE_BUILDROOTURL"X" == "XX" ]; then
    errMsg="$!SSE_BUILDROOTURL [$SSE_BUILDROOTURL] or $!SSE_BUILD_ID [$SSE_BUILD_ID] not set!!"
    exitWithErrMsg "$errMsg"
  else
    echo "using SSE common repository, $!SSE_BUILDROOTURL [$SSE_BUILDROOTURL], $!SSE_BUILD_ID [$SSE_BUILD_ID]"
    RepoLoc=$SSE_BUILDROOTURL/$SSEProductOfferingSuffix
  fi
fi
if [ "CLM" == $appMediaType ]; then 
  ## using CLM repo
  if [ "X"$CLM_BUILD_ID"X" == "XX" ] || [ "X"$CLM_BUILDROOTURL"X" == "XX" ]; then
    errMsg="$!CLM_BUILDROOTURL [$CLM_BUILDROOTURL] or $!CLM_BUILD_ID [$CLM_BUILD_ID] not set!"
    exitWithErrMsg "$errMsg"
  else
    echo "using CLM common repository, $!CLM_BUILDROOTURL [$CLM_BUILDROOTURL], $!CLM_BUILD_ID [$CLM_BUILD_ID]"
    RepoLoc=$CLM_BUILDROOTURL/$CLMProductOfferingSuffix
  fi
fi

if [ "FILE" == $appMediaType ]; then 
  ## using file repo ${mediaRoot}/${appMediaRoot}/${appFile}
  if [ "XX" == "X"${mediaRoot}"X" ] || [ "XX" == "X"${appMediaRoot}"X" ] || [ "XX" == "X"${appFile}"X" ]; then
    errMsg="$!mediaRoot [$mediaRoot] or $!appMediaRoot [$appMediaRoot] or $!appFile [$appFile] not set!"
    exitWithErrMsg "$errMsg"
  else
    repoFileConfigLocation=${mediaRoot}"/"${appMediaRoot}"/"${appFile}
    echo "using file repository, $!repoFileConfigLocation [$repoFileConfigLocation]"
    RepoLoc="file:"$repoFileConfigLocation
  fi
fi
if [ "ZIP" == $appMediaType ]; then
  # need to calculate $repoZipFileLocation
  
  if [ "FILE" == $mediaAccess ]; then
    ## using file ${mediaRoot}/${appMediaRoot}/${appFile}
    if [ "XX" == "X"${mediaRoot}"X" ] || [ "XX" == "X"${appMediaRoot}"X" ] || [ "XX" == "X"${appFile}"X" ]; then
      errMsg="$!mediaRoot [$mediaRoot] or $!appMediaRoot [$appMediaRoot] or $!appFile [$appFile] not set!"
      exitWithErrMsg "$errMsg"
    else
      repoZipFileLocation=${mediaRoot}"/"${appMediaRoot}"/"${appFile}
    fi
  fi

  if [ "HTTP" == $mediaAccess ] || [ "HTTPS" == $mediaAccess ]; then
    if [ "X"$appFile"X" == "XX" ]; then
      errMsg="$!appFile [$appFile] not set!"
      exitWithErrMsg "$errMsg"
    else
      tempStr=`echo ${appFile} | cut -c -4`
      if [ "http" == $tempStr ]; then
        ## $appFile conatins the full URL
        repoZipFileLocation=${appFile}
      else
        # calculate the URL = ${mediaServer}/${appMediaRoot}/${appFile}
        if [ "XX" == "X"${mediaServer}"X" ] || [ "XX" == "X"${appMediaRoot}"X" ] || [ "XX" == "X"${appFile}"X" ]; then
          errMsg="$!mediaServer [$mediaServer] or $!appMediaRoot [$appMediaRoot] or $!appFile [$appFile] not set!"
          exitWithErrMsg "$errMsg"
        else
          repoZipFileLocation=${mediaServer}"/"${appMediaRoot}"/"${appFile}
        fi
      fi
    fi
  fi

  ## using zipped up file repo
  if [ "X"$repoZipFileLocation"X" == "XX" ]; then
    errMsg="$!repoZipFileLocation [$repoZipFileLocation] not set!"
    exitWithErrMsg "$errMsg"
  else
    echo "using zipped up file repository, $!repoZipFileLocation [$repoZipFileLocation]"
    zipFileName=$(basename $repoZipFileLocation)
    
    ## download the zip (http) OR copy the zip (nfs)
    #downloadDir=${mediaRoot}"/"${appMediaRoot}
    downloadDir=${QD_InternalMedia}"/"${appMediaRoot}
    repoDir=${downloadDir}"/repo"
    mkdir -p ${downloadDir}
    mkdir -p ${repoDir}
    cd ${downloadDir}
    tempStr=`echo ${repoZipFileLocation} | cut -c -4`
    timestamp=`date +%s`
    echo "DEBUG (ready to get ZIP) : current epoch time is ["$timestamp"] Sec"
    if [ "http" == $tempStr ]; then
      ## download the zip from the url
      downloadHttpZip $repoZipFileLocation
      zipNeedsDeleted=TRUE
    else
      # only download a copy if NFS has been setup
      if [ "TRUE" == ${nfsEnabled} ]; then
        # copy the zip
        copyZip $repoZipFileLocation
        zipNeedsDeleted=TRUE
      fi
    fi
    timestamp=`date +%s`
    echo "DEBUG (ready to unzip ZIP) : current epoch time is ["$timestamp"] Sec"
    ## unzip
    if [ "http" == $tempStr ]; then
      unzipZip ${downloadDir}"/"${zipFileName} ${repoDir}
      unzipFolderNeedsDeleted=TRUE
    else
      if [ "TRUE" == ${nfsEnabled} ]; then
        unzipZip ${downloadDir}"/"${zipFileName} ${repoDir}
        unzipFolderNeedsDeleted=TRUE
      else
        unzipZip $repoZipFileLocation ${repoDir}
        unzipFolderNeedsDeleted=TRUE
      fi
    fi
    timestamp=`date +%s`
    echo "DEBUG (ZIP unzipped) : current epoch time is ["$timestamp"] Sec"
    
    fileConfigLocation=${repoDir}"/repository.config"
    checkFileExists ${fileConfigLocation}
    
    echo "using unzipped  file repository, $!fileConfigLocation [$fileConfigLocation]"
    RepoLoc="file:"${fileConfigLocation}
  fi
fi


## =============================================================
## === exit if only creating a media server

if [ "TRUE" == $createMediaOnly ]; then
  echo "media server update done"
  exit 0
fi


## ======================================================================
## ==== set control flags ====
## decide when an app can be included and which license to use
echo "setting control flags"

skipInstallFlag=FALSE
##sseRepoFlag=FALSE
##rhapsodyLicenseRepoFlag=FALSE

# -- potential applications
jtsFlag=FALSE
ccmFlag=FALSE
qmFlag=FALSE
rmFlag=FALSE
dmFlag=FALSE
vvcFlag=FALSE
relmFlag=FALSE
lqeFlag=FALSE
lqejrsFlag=FALSE
dccFlag=FALSE
dccjrsFlag=FALSE
rsFlag=FALSE
rsjrsFlag=FALSE
gcFlag=FALSE
ldxFlag=FALSE

clmLicenseFlag=FALSE


# -- potential xml profile sections
profileFlag=FALSE


# --- For Quick Deployer section ----
export IFS=","
validComponentFlag=FALSE
for Install_Component in $APPS
do
  echo "Install_Component: [$Install_Component]"
  
  ## -- individual apps
  if [ $Install_Component == "jts" ]; then
    INSTALLED_COMPONENTS=${INSTALLED_COMPONENTS}","${Install_Component}
    validComponentFlag=TRUE
    jtsFlag=TRUE  
    clmLicenseFlag=TRUE
    profileFlag=TRUE
  fi
  if [ $Install_Component == "gc" ]; then
    INSTALLED_COMPONENTS=${INSTALLED_COMPONENTS}","${Install_Component}
    validComponentFlag=TRUE
    gcFlag=TRUE
    profileFlag=TRUE
  fi
  if [ $Install_Component == "ldx" ]; then
    INSTALLED_COMPONENTS=${INSTALLED_COMPONENTS}","${Install_Component}
    validComponentFlag=TRUE
    ldxFlag=TRUE
    profileFlag=TRUE
  fi
  if [ $Install_Component == "ccm" ]; then
    INSTALLED_COMPONENTS=${INSTALLED_COMPONENTS}","${Install_Component}
    validComponentFlag=TRUE
    ccmFlag=TRUE
    profileFlag=TRUE
  fi
  if [ $Install_Component == "qm" ]; then
    INSTALLED_COMPONENTS=${INSTALLED_COMPONENTS}","${Install_Component}
    validComponentFlag=TRUE
    qmFlag=TRUE
    profileFlag=TRUE
  fi
  if [ $Install_Component == "rm" ]; then
    INSTALLED_COMPONENTS=${INSTALLED_COMPONENTS}","${Install_Component}
    validComponentFlag=TRUE
    rmFlag=TRUE
    profileFlag=TRUE
  fi
  if [ $Install_Component == "dm" ]; then
    INSTALLED_COMPONENTS=${INSTALLED_COMPONENTS}","${Install_Component}
    validComponentFlag=TRUE
    ## add vvc 12th march 2015
    dmFlag=TRUE
    profileFlag=TRUE
  fi
  if [ $Install_Component == "vvc" ]; then
    INSTALLED_COMPONENTS=${INSTALLED_COMPONENTS}","${Install_Component}
    validComponentFlag=TRUE
    vvcFlag=TRUE
    profileFlag=TRUE
  fi
  if [ $Install_Component == "relm" ]; then
    INSTALLED_COMPONENTS=${INSTALLED_COMPONENTS}","${Install_Component}
    validComponentFlag=TRUE
    relmFlag=TRUE
    profileFlag=TRUE
  fi
  if [ $Install_Component == "lqe" ]; then
    INSTALLED_COMPONENTS=${INSTALLED_COMPONENTS}","${Install_Component}
    validComponentFlag=TRUE
    lqeFlag=TRUE
    profileFlag=TRUE
    # lqe is part of jrs package
    lqejrsFlag=TRUE
  fi
  if [ $Install_Component == "dcc" ]; then
    INSTALLED_COMPONENTS=${INSTALLED_COMPONENTS}","${Install_Component}
    validComponentFlag=TRUE
    dccFlag=TRUE
    # dcc is part of jrs package
    dccjrsFlag=TRUE
    profileFlag=TRUE
  fi
  if [ $Install_Component == "rs" ]; then
    INSTALLED_COMPONENTS=${INSTALLED_COMPONENTS}","${Install_Component}
    validComponentFlag=TRUE
    rsFlag=TRUE
    # rs is part of jrs package
    rsjrsFlag=TRUE
    profileFlag=TRUE
  fi
  
  ## -- groupings of aps
  if [ $Install_Component == "clm" ]; then
    INSTALLED_COMPONENTS=${INSTALLED_COMPONENTS}","${Install_Component}
    validComponentFlag=TRUE
    ## add relm 6th march 2015
    ##{jts/ccm/qm/rm/rs/dcc/relm}
    jtsFlag=TRUE
    ccmFlag=TRUE
    qmFlag=TRUE
    rmFlag=TRUE
    dccFlag=TRUE
    rsFlag=TRUE
    # dcc & rs are part of jrs package
    dccjrsFlag=TRUE
    rsjrsFlag=TRUE
    relmFlag=TRUE
    ##vvcFlag=TRUE   ## vvc is removed on clm dept topology
    ##lqeFlag=TRUE   ## no lqe on clm dept server
    clmLicenseFlag=TRUE
    profileFlag=TRUE
    gcFlag=TRUE
    ldxFlag=TRUE
  fi
  
  if [ $Install_Component == "sse" ]; then
    INSTALLED_COMPONENTS=${INSTALLED_COMPONENTS}","${Install_Component}
    validComponentFlag=TRUE
    ## add relm 6th march 2015
    ##{jts/ccm/qm/rm/dm/vvc/rs/dcc/relm}
    jtsFlag=TRUE
    ccmFlag=TRUE
    qmFlag=TRUE
    rmFlag=TRUE
    dmFlag=TRUE
    vvcFlag=TRUE
    ##lqeFlag=TRUE   ## no lqe on sse dept server
    dccFlag=TRUE
    rsFlag=TRUE
    # dcc & rs are part of jrs package
    dccjrsFlag=TRUE
    rsjrsFlag=TRUE
    relmFlag=TRUE
    clmLicenseFlag=TRUE
    profileFlag=TRUE
    gcFlag=TRUE
    ldxFlag=TRUE
  fi

done

# unset IFS, so rest of code will work
unset IFS

# check there is something to install
if [ $validComponentFlag == "FALSE" ]; then
  echo "ERROR: no valid component in ["${APPS}"]"
  echo "only support [$SUPPORTED_COMPONENT]"
  exit 1
fi

# remove leading comma
INSTALLED_COMPONENTS=`echo ${INSTALLED_COMPONENTS} | cut -c 2-`


## ======================================================================
## ==== create IM install XML ====
cd ${workingDir}
echo "Create IM response file from template [$IM_templateFile]"

if [ -f $IMXML ]; then
  echo "deleting old version of $IMXML"
  rm -f $IMXML
fi
cp $IM_templateFile $IMXML


## -- sed rules
# -i : 
# s : substitute
# g : every occurrence
# %lookFor%replace% 

## assume sed does not error
## do all substitutions directly on the $IMXML file
## sseRepo600 currently contains {jts, ccm, qm, rm, sseLic, dm, lqe, rs, dcc, relm, gc, ldx}
## clmRepo600 currently contains {jts, ccm, qm, rm, clmLic, lqe, rs, dcc, relm, gc, ldx}

## -- repos 
echo "RepoLoc = [$RepoLoc]"
sed -i s%_IBMQD_IM_REPO_%$RepoLoc%g $IMXML
sed -i s%!--_BG_IBMQD_REPO_repository%repository%g $IMXML
sed -i s%/_END_BG_IBMQD_REPO_--%/%g $IMXML


# check apps in repos
## OFFERINGS CAN GO IN HERE LATER ##

# - common first
if [ "SSE" == $appMediaContent ] || [ "CE" == $appMediaContent ] || [ "CLM" == $appMediaContent ]; then

  if [ $ccmFlag == "TRUE" ]; then
    echo "sourcing CCM from the [${appMediaContent}] repository"
    sed -i s%!--_BG_CCM_OFFER_offering%offering%g $IMXML
    sed -i s%/_END_CCM_OFFER_--%/%g $IMXML  
  fi
  
  if [ $jtsFlag == "TRUE" ]; then
    echo "sourcing JTS from the [${appMediaContent}] repository"
    sed -i s%!--_BG_JTS_OFFER_offering%offering%g $IMXML
    sed -i s%/_END_JTS_OFFER_--%/%g $IMXML
  fi
  
  if [ $gcFlag == "TRUE" ]; then
    echo "sourcing GC from the [${appMediaContent}] repository"
    sed -i s%!--_BG_GC_OFFER_offering%offering%g $IMXML
    sed -i s%/_END_GC_OFFER_--%/%g $IMXML
  fi
  
  if [ $ldxFlag == "TRUE" ]; then
    echo "sourcing LDX from the [${appMediaContent}] repository"
    sed -i s%!--_BG_LDX_OFFER_offering%offering%g $IMXML
    sed -i s%/_END_LDX_OFFER_--%/%g $IMXML
  fi
  
  if [ $qmFlag == "TRUE" ]; then
    echo "sourcing QM from the [${appMediaContent}] repository"
    sed -i s%!--_BG_QM_OFFER_offering%offering%g $IMXML
    sed -i s%/_END_QM_OFFER_--%/%g $IMXML
  fi
  
  if [ $rmFlag == "TRUE" ]; then
    echo "sourcing RM from the [${appMediaContent}] repository"
    sed -i s%!--_BG_RM_OFFER_offering%offering%g $IMXML
    sed -i s%/_END_RM_OFFER_--%/%g $IMXML
  fi

  
  ## only want relm from the RELM repo (no rs or lqe)
  # -- relm has features inside it's offering
  if [ $relmFlag == "TRUE" ]; then
    echo "sourcing RELM from the [${appMediaContent}] repository"
    sed -i s%!--_BG_RELM_OFFER_offering%offering%g $IMXML
    sed -i s%/_END_RELM_OFFER_--%/%g $IMXML
    relmFeatures=relm
    echo "relm features [$relmFeatures]"
    sed -i s%_RELM_FEATURES_%$relmFeatures%g $IMXML
  fi
  
  ## rs, dcc and lqe share the JRS package in the repo  
  if [ $dccjrsFlag == "TRUE" ]; then
    echo "sourcing DCC from the [${appMediaContent}] repository"
  fi
  if [ $lqejrsFlag == "TRUE" ]; then
    echo "sourcing LQE from the [${appMediaContent}] repository"
  fi
  if [ $rsjrsFlag == "TRUE" ]; then
    echo "sourcing RS from the [${appMediaContent}] repository"
  fi
  # -- select the features inside it's offering
  if [ $dccjrsFlag == "TRUE" ] || [ $lqejrsFlag == "TRUE" ] || [ $rsjrsFlag == "TRUE" ]; then
    sed -i s%!--_BG_JRS_OFFER_offering%offering%g $IMXML
    sed -i s%/_END_JRS_OFFER_--%/%g $IMXML
    echo "dccjrsFlag [$dccjrsFlag] lqejrsFlag [$lqejrsFlag] rsjrsFlag [$rsjrsFlag]"
    if [ $dccjrsFlag == "TRUE" ]; then
      if [ $lqejrsFlag == "TRUE" ]; then
        if [ $rsjrsFlag == "TRUE" ]; then
          jrsFeatures=dcc,lqe,jrs
        else
          jrsFeatures=dcc,lqe
        fi
        echo "jrs features [$jrsFeatures]"
        sed -i s%_JRS_FEATURES_%"$jrsFeatures"%g $IMXML
      else
        if [ $rsjrsFlag == "TRUE" ]; then
          jrsFeatures=dcc,jrs
        else
          jrsFeatures=dcc
        fi
        echo "jrs features [$jrsFeatures]"
        sed -i s%_JRS_FEATURES_%$jrsFeatures%g $IMXML
      fi  
    else 
      if [ $lqejrsFlag == "TRUE" ]; then
        if [ $rsjrsFlag == "TRUE" ]; then
          jrsFeatures=lqe,jrs
        else
          jrsFeatures=lqe
        fi
        echo "jrs features [$jrsFeatures]"
        sed -i s%_JRS_FEATURES_%$jrsFeatures%g $IMXML
      else
        if [ $rsjrsFlag == "TRUE" ]; then
          jrsFeatures=jrs
        else
          ## no substitution needed ??
          jrsFeatures=none
        fi
        echo "jrs features [$jrsFeatures]"
        sed -i s%_JRS_FEATURES_%$jrsFeatures%g $IMXML
      fi
    fi
  fi


fi

# - specific to one or other
if [ "SSE" == $appMediaContent ] || [ "CE" == $appMediaContent ]; then
  if [ $dmFlag == "TRUE" ]; then
    echo "sourcing DM from the [${appMediaContent}] repository"
    sed -i s%!--_BG_DM_OFFER_offering%offering%g $IMXML
    sed -i s%/_END_DM_OFFER_--%/%g $IMXML
  fi
  if [ $vvcFlag == "TRUE" ]; then
    echo "sourcing VVC from the [${appMediaContent}] repository"
    sed -i s%!--_BG_VVC_OFFER_offering%offering%g $IMXML
    sed -i s%/_END_VVC_OFFER_--%/%g $IMXML
  fi
  
  
  if [ $clmLicenseFlag == "TRUE" ]; then
    echo "sourcing SSE licenses from the [${appMediaContent}] repository"
    sed -i s%!--_BG_SSE_LICENSE_OFFER_offering%offering%g $IMXML
    sed -i s%/_END_SSE_LICENSE_OFFER_--%/%g $IMXML
  fi
  
fi

if [ "CLM" == $appMediaContent ]; then
  if [ $dmFlag == "TRUE" ]; then
    echo "ERROR: DM does not exist in the [${appMediaContent}] repository"
    skipInstallFlag=TRUE
  fi
  if [ $vvcFlag == "TRUE" ]; then
    echo "ERROR: VVC does not exist in the [${appMediaContent}] repository"
    skipInstallFlag=TRUE
  fi
  
  if [ $clmLicenseFlag == "TRUE" ]; then
    echo "sourcing CLM licenses from the [${appMediaContent}] repository"
    sed -i s%!--_BG_CLM_LICENSE_OFFER_offering%offering%g $IMXML
    sed -i s%/_END_CLM_LICENSE_OFFER_--%/%g $IMXML
  fi
  
fi





## -- OS folders
## windows not used _WIN_ECLIPSE_CACHE_LOCATION_ = C:/IBM/JazzTeamServer
## windows not used _WIN_INSTALL_LOCATION_ = C:/IBM/IBMIMShared
## linux _LINUX_ECLIPSE_CACHE_LOCATION_ = /opt/IBM/IBMIMShared
## linux _LINUX_INSTALL_LOCATION_ = /opt/IBM/JazzTeamServer
## assuming $CLM_HOME=/opt/IBM/JazzTeamServer
## assuming $CLM_CACHE=/opt/IBM/IBMIMShared

## -- OS is LINUX
if [ $profileFlag == "TRUE" ]; then
  echo "enabling the sse profile"
  sed -i s%_LINUX_INSTALL_LOCATION_%$CLM_HOME%g $IMXML
  sed -i s%!--_BG_LINUX_INSTALL_profile%profile%g $IMXML
  sed -i s%!--_BG_LINUX_INSTALL_data%data%g $IMXML
  sed -i s%/_END_LINUX_INSTALL_--%/%g $IMXML
  sed -i s%"_END_LINUX_INSTALL_--"%""%g $IMXML
  sed -i s%"<!--_BG_HIDE_PROFILE_DATA_"%""%g $IMXML
  sed -i s%"_END_HIDE_PROFILE_DATA_-->"%""%g $IMXML
fi

## cache is common to all profiles
sed -i s%_LINUX_ECLIPSE_CACHE_LOCATION_%$CLM_CACHE%g $IMXML
sed -i s%!--_BG_LINUX_INSTALL_preference%preference%g $IMXML
sed -i s%/_END_LINUX_INSTALL_preference_--%/%g $IMXML


## =============================================================
## === only continue if all required apps are in the repo ====
if [ $skipInstallFlag == "TRUE" ]; then
  echo "ERROR: one or more of the required apps are missing from the repository"
  exit 1
else
  echo "all required repo apps are in the repository, continue to install step" 
fi


## =============================================================
## === DEBUG early exit

if [ "TRUE" == $debugDoNotInstall ]; then
  echo "DEBUG: XML response file created but exiting prior to installing applications"
  exit 0
fi


## ======================================================================
## ==== install component via IM ====
echo "Install [$INSTALLED_COMPONENTS] to the system, using Installation Manager response file [$IMXML]"
IM_USERNAME=`ls -l /opt/IBM/InstallationManager/eclipse/IBMIM | cut -d' ' -f 3`
## su -c "./IBMIM --launcher.ini silent-install.ini -input $IMXML -secureStorageFile /tmp/IM_Keyring/IM.Cred -masterPasswordFile /tmp/IM_Keyring/password.txt -acceptLicense" -- $IM_USERNAME
IMexe="IBMIM --launcher.ini silent-install.ini -input $IMXML -acceptLicense"

# only need credentials for a "secure repo"
if [ "CLM" == $appMediaType ] || [ "CE" == $appMediaType ] || [ "SSE" == $appMediaType ]; then
  IMexe="$IMexe -secureStorageFile $IMsecureStorageFile -masterPasswordFile $IMpasswordFile"
fi

echo IM command [$IMexe]

cd $IM_LOCATION
echo "Installing [$INSTALLED_COMPONENTS] ..."
su -c "./$IMexe" -- $IM_USERNAME
if [ $? -gt 0 ]; then
  echo "ERROR: [$INSTALLED_COMPONENTS] install failed"
  exit 1
fi


## ======================================================================
## ==== make installation executable ====

if [ -d $CLM_HOME ]; then
  echo "make $CLM_HOME executable"
  chmod -R 777 $CLM_HOME
  ls -la $CLM_HOME
fi


## ======================================================================  
## ==== check war file installed ====
echo "check war file exists"

## -- the war file locations
jtsWarFile=$CLM_HOME/server/webapps/jts.war
ccmWarFile=$CLM_HOME/server/webapps/ccm.war
qmWarFile=$CLM_HOME/server/webapps/qm.war
rmWarFile=$CLM_HOME/server/webapps/rm.war
dmWarFile=$CLM_HOME/server/webapps/dm.war
vvcWarFile=$CLM_HOME/server/webapps/vvc.war
relmWarFile=$CLM_HOME/server/webapps/relm.war
lqeWarFile=$CLM_HOME/server/webapps/lqe.war
ldxWarFile=$CLM_HOME/server/webapps/ldx.war
gcWarFile=$CLM_HOME/server/webapps/gc.war
dccWarFile=$CLM_HOME/server/webapps/dcc.war
rsWarFile=$CLM_HOME/server/webapps/rs.war



## -- check war exists, fail on first missing file

if [ $jtsFlag == "TRUE" ]; then
  checkFileExists $jtsWarFile
fi

if [ $gcFlag == "TRUE" ]; then
  checkFileExists $gcWarFile
fi

if [ $ldxFlag == "TRUE" ]; then
  checkFileExists $ldxWarFile
fi
if [ $ccmFlag == "TRUE" ]; then
  checkFileExists $ccmWarFile
fi

if [ $qmFlag == "TRUE" ]; then
  checkFileExists $qmWarFile
fi

if [ $rmFlag == "TRUE" ]; then
  checkFileExists $rmWarFile
fi

if [ $dmFlag == "TRUE" ]; then
  checkFileExists $dmWarFile
fi

if [ $vvcFlag == "TRUE" ]; then
  checkFileExists $vvcWarFile
fi

if [ $relmFlag == "TRUE" ]; then
  checkFileExists $relmWarFile
fi

if [ $lqeFlag == "TRUE" ]; then
  checkFileExists $lqeWarFile
fi

if [ $dccFlag == "TRUE" ]; then
  checkFileExists $dccWarFile
fi

if [ $rsFlag == "TRUE" ]; then
  checkFileExists $rsWarFile
fi

echo "component [$INSTALLED_COMPONENTS] installed"


## =======================================================
## === installing 32 bit libXdmcp.so.6 for DM 
## === is now a preRequisite on the system 
## =======================================================


# ====================================================
# tidy up by deleting anything downloaded or unzipped
if [ "TRUE" == $unzipFolderNeedsDeleted ]; then
  echo "Removing the directory ["${repoDir}"]"
  rm -Rf ${repoDir}
fi
if [ "TRUE" == $zipNeedsDeleted ]; then
  echo "Removing the directory ["${downloadDir}"]"
  rm -Rf ${downloadDir}
fi


## =======================================================
## === finished ====
timestamp=`date +%s`
echo "DEBUG (EOF) : current epoch time is ["$timestamp"] Sec"
echo "SUCCESS: installation complete"
exit 0
