#!/bin/sh
#********************************************************************************
# Licensed Materials - Property of IBM
# IBM Quick Deployer
# (c) Copyright IBM Corporation 2015. All Rights Reserved.
#
# U.S. Government Users Restricted Rights:
# Use, duplication or disclosure restricted by GSA ADP Schedule
# Contract with IBM Corp.
#
#********************************************************************************
targetFile=/etc/security/limits.conf
tempFile=temp_limits.conf

nofilehardlimit="65536"
nofilesoftlimit="65536"
corehardlimit="unlimited"
coresoftlimit="unlimited"
stackhardlimit="32768"
stacksoftlimit="32768"

nofilehard="hard nofile $nofilehardlimit"
nofilesoft="soft nofile $nofilesoftlimit"
corehard="hard core $corehardlimit"
coresoft="soft core $coresoftlimit"
stackhard="hard stack $stackhardlimit"
stacksoft="soft stack $stacksoftlimit"

foundnofilehard=FALSE
foundnofilesoft=FALSE
foundcorehard=FALSE
foundcoresoft=FALSE
foundstackhard=FALSE
foundstacksoft=FALSE

profileFile=/etc/profile
echo "ulimit -u 10000" >> $profileFile

cp $targetFile $targetFile.BAK
if [ -f $tempFile ]; then
  rm -f $tempFile
fi
touch $tempFile

while read currentline
do

	
	#END OF FILE (last line)
	if [[ $currentline == *End*of*file* ]]; then

		if [[ $foundnofilehard == "FALSE" ]]; then
			echo "[nofilehard] line never found, so need to add it"
			echo "* ${nofilehard}" >> $tempFile		
		fi
		if [[ $foundnofilesoft == "FALSE" ]]; then
			echo "[nofilesoft] line never found, so need to add it"
			echo "* ${nofilesoft}" >> $tempFile
		fi
		if [[ $foundcorehard == "FALSE" ]]; then
			echo "[corehard] line never found, so need to add it"
			echo "* ${corehard}" >> $tempFile
		fi
		if [[ $foundcoresoft == "FALSE" ]]; then
			echo "[coresoft] line never found, so need to add it"
			echo "* ${coresoft}" >> $tempFile
		fi		
		if [[ $foundstackhard == "FALSE" ]]; then
			echo "[stackhard] line never found, so need to add it"
			echo "* ${stackhard}" >> $tempFile
		fi
		if [[ $foundstacksoft == "FALSE" ]]; then
			echo "[stacksoft] line never found, so need to add it"
			echo "* ${stacksoft}" >> $tempFile
		fi

		echo "remember to add last line  [$currentline]"
		echo "${currentline}" >> $tempFile

	
	#COMMENT
	elif [[ $currentline == "#"* ]]; then
		## echo "comment, just use current line [$currentline]"
		echo "$currentline" >> $tempFile


	#NOFILE
	# does line contain the right words
	# [yes] does word contain right size
	#   [yes] do nothing
	#   [no] replace with new string
	# [no] do nothing
	elif [[ $currentline == *hard*nofile* ]]; then
		foundnofilehard=TRUE
		if [[ $currentline == *${nofilehardlimit}* ]]; then
			## echo "[nofilehard] line [$currentline] is a match, so no need to change"
			echo "${currentline}" >> $tempFile
		else
			echo "[nofilehard] replace [$currentline] with [* ${nofilehard}]"
			echo "* ${nofilehard}" >> $tempFile
		fi

	elif [[ $currentline == *soft*nofile* ]]; then
		foundnofilesoft=TRUE
		if [[ $currentline == *${nofilesoftlimit}* ]]; then
			## echo "[nofilesoft] line [$currentline] is a match, so no need to change"
			echo "${currentline}" >> $tempFile
		else
			echo "[nofilesoft] replace [$currentline] with [* ${nofilesoft}]"
			echo "* ${nofilesoft}" >> $tempFile
		fi

	##CORE
	elif [[ $currentline == *hard*core* ]]; then
		foundcorehard=TRUE
		if [[ $currentline == *${corehardlimit}* ]]; then
			## echo "[corehard] line [$currentline] is a match, so no need to change"
			echo "${currentline}" >> $tempFile
		else
			echo "[corehard] replace [$currentline] with [* ${corehard}]"
			echo "* ${corehard}" >> $tempFile
		fi

	elif [[ $currentline == *soft*core* ]]; then
		foundcoresoft=TRUE
		if [[ $currentline == *${coresoftlimit}* ]]; then
			## echo "[coresoft] line [$currentline] is a match, so no need to change"
			echo "${currentline}" >> $tempFile
		else
			echo "[coresoft] replace [$currentline] with [* ${coresoft}]"
			echo "* ${coresoft}" >> $tempFile
		fi


	##STACK
	elif [[ $currentline == *hard*stack* ]]; then
		foundstackhard=TRUE
		if [[ $currentline == *${stackhardlimit}* ]]; then
			## echo "[stackhard] line [$currentline] is a match, so no need to change"
			echo "${currentline}" >> $tempFile
		else
			echo "[stackhard] replace [$currentline] with [* ${stackhard}]"
			echo "* ${stackhard}" >> $tempFile
		fi

	elif [[ $currentline == *soft*stack* ]]; then
		foundstacksoft=TRUE
		if [[ $currentline == *${stacksoftlimit}* ]]; then
			## echo "[stacksoft] line [$currentline] is a match, so no need to change"
			echo "${currentline}" >> $tempFile
		else
			echo "[stacksoft] replace [$currentline] with [* ${stacksoft}]"
			echo "* ${stacksoft}" >> $tempFile
		fi
		

	# OTHER LINES
	else
		## echo "no match, just use current line [$currentline]"
		echo "$currentline" >> $tempFile
	fi

done < $targetFile

# make the update permananet
cp -f $tempFile $targetFile
rm -f $tempFile 
echo "update completed"
exit 0 

