#!/bin/sh
#********************************************************************************
# Licensed Materials - Property of IBM
# IBM Quick Deployer
# (c) Copyright IBM Corporation 2015. All Rights Reserved.
#
# U.S. Government Users Restricted Rights:
# Use, duplication or disclosure restricted by GSA ADP Schedule
# Contract with IBM Corp.
#
#********************************************************************************

#############
## FUNCTIONS 
#############


exitWithErrMsg()
{
  tempString=$1
  echo "-- ERROR [${scriptName}] --"
  echo "-- message: $tempString"
  exit 1
}


## usage checkFileExists tempFile
checkFileExists()
{
  tempFile=$1
  if [ -f $tempFile ]; then
    echo "file [$tempFile] located"
  else
    echo "ERROR: [$tempFile] does not exist"
    exit 1
  fi
}


downloadHttpZip()
{
  fileUrl=$1
  filename=$(basename $fileUrl)

  sh $AUTO_PREP/MediaParameters/doWget.sh $fileUrl
  if [ $? == 0 ]
  then
    echo "download complete"
    checkFileExists $filename
  else
    errMsg="failed to download file ["${filename}"]"
    exitWithErrMsg "$errMsg"
  fi
}

copyZip()
{
  file=$1
  filename=$(basename $file)
  echo "copy ["${file}"] to ["${filename}"]"
  cp $file $filename
  if [ $? == 0 ]
  then
    echo "copy complete" 
    checkFileExists $filename
  else
    errMsg="failed to copy file ["${filename}"]"
    exitWithErrMsg "$errMsg"
  fi
}


####################
##                ##
## ==== MAIN ==== ##
##                ##
####################

timestamp=`date +%s`
echo "DEBUG (start) : current epoch time is ["$timestamp"] Sec"


# set up local environment for this script
scriptName=$0
workingDir=`pwd -P`
envProp=/etc/env.properties
scriptProp=./script.properties
. $envProp
. $scriptProp

# get credentials
userCreds=$AUTO_PREP/UserParameters/userCreds.properties
. $userCreds

# get media properties
mediaProp=$AUTO_PREP/MediaParameters/media.properties
. $mediaProp


if [ "ZIP" == $db2MediaType ] || [ "FILE" == $db2MediaType ]; then 
  echo "using [${db2MediaType}] media location type"
else
  errMsg="["${db2MediaType}"] media location type not supported"
  exitWithErrMsg "$errMsg"
fi


if [ "X"$nfsEnabled"X" == "XX" ]; then
  echo "no NFS drive exists, assuming license file is local"
  nfsEnabled=FALSE
else
  # need to check value
  if [ "FALSE" == $nfsEnabled ]; then
    echo "no NFS drive exists, assuming license file is local"
    nfsEnabled=FALSE
  elif [ "TRUE" == $nfsEnabled ]; then 
    echo "NFS drive exists, assuming license file is remote"
  else
    errMsg="["${nfsEnabled}"] nfsEnabled not supported"
    exitWithErrMsg "$errMsg"
  fi
fi

if [ "X"$createMediaOnly"X" == "XX" ]; then
  echo "installing DB2 license"
  createMediaOnly=FALSE
else
  # need to check value
  if [ "FALSE" == $createMediaOnly ]; then
    echo "installing DB2 license"
    createMediaOnly=FALSE
  elif [ "TRUE" == $createMediaOnly ]; then 
    echo "adding DB2 license to media server"
  else
    errMsg="["${createMediaOnly}"] createMediaOnlyFlag not supported"
    exitWithErrMsg "$errMsg"
  fi
fi


if [ "X"$debugDoNotInstall"X" == "XX" ]; then
  echo "installing DB2 license"
  debugDoNotInstall=FALSE
else
  # need to check value
  if [ "FALSE" == $debugDoNotInstall ]; then
    echo "installing DB2 license"
    debugDoNotInstall=FALSE
  elif [ "TRUE" == $debugDoNotInstall ]; then
    echo "DEBUG: will exit prior to installing DB2"
  else
    errMsg="["${debugDoNotInstall}"] debugDoNotInstallFlag not supported"
    exitWithErrMsg "$errMsg"
  fi
fi


## ======================================================================
## set $db2LicenseFile location
zipNeedsDeleted=FALSE
if [ "FILE" == $db2MediaType ]; then 
  ## using file ${mediaRoot}/${db2MediaRoot}/${db2License}
  if [ "XX" == "X"${mediaRoot}"X" ] || [ "XX" == "X"${db2MediaRoot}"X" ] || [ "XX" == "X"${db2License}"X" ]; then
    errMsg="$!mediaRoot [$mediaRoot] or $!db2MediaRoot [$db2MediaRoot] or $!db2License [$db2License] not set!"
    exitWithErrMsg "$errMsg"
  else
    db2LicenseFolder=${mediaRoot}"/"${db2MediaRoot}
    db2LicenseFile=${db2License}
    db2LicenseFileLocation=${db2LicenseFolder}"/"${db2LicenseFile}
    echo "using file $!db2LicenseFileLocation [$db2LicenseFileLocation]"
    checkFileExists ${db2LicenseFileLocation}
  fi
fi
if [ "ZIP" == $db2MediaType ]; then
  # need to calculate $db2ZipFileLocation
  
  if [ "FILE" == $mediaAccess ]; then
    ## using file ${mediaRoot}/${db2MediaRoot}/${db2License}
    if [ "XX" == "X"${mediaRoot}"X" ] || [ "XX" == "X"${db2MediaRoot}"X" ] || [ "XX" == "X"${db2License}"X" ]; then
      errMsg="$!mediaRoot [$mediaRoot] or $!db2MediaRoot [$db2MediaRoot] or $!db2License [$db2License] not set!"
      exitWithErrMsg "$errMsg"
    else
      # db2ZipFileLocation=${mediaRoot}"/"${db2MediaRoot}"/"${db2License}
      db2ZipFileFolder=${mediaRoot}"/"${db2MediaRoot}
      db2ZipFileLocation=${db2ZipFileFolder}"/"${db2License}
      checkFileExists ${db2ZipFileLocation}
    fi 
  fi
  if [ "HTTP" == $mediaAccess ] || [ "HTTPS" == $mediaAccess ]; then
    if [ "X"$db2License"X" == "XX" ]; then
      tempStr="notURL"
    else
      tempStr=`echo ${db2License} | cut -c -4`
    fi
    if [ "http" == $tempStr ]; then
      ## $db2License conatins the full URL
      if [ "XX" == "X"${db2License}"X" ]; then
        errMsg="$!db2License [$db2License] not set!"
        exitWithErrMsg "$errMsg"
      else
        db2ZipFileLocation=${db2License}
      fi
    else
      # calculate the URL = ${mediaServer}/${db2MediaRoot}/${db2Version}/${db2License}
      if [ "XX" == "X"${mediaServer}"X" ] || [ "XX" == "X"${db2MediaRoot}"X" ] || [ "XX" == "X"${db2Version}"X" ] || [ "XX" == "X"${db2License}"X" ]; then
        errMsg="$!mediaServer [$mediaServer] or $!db2MediaRoot [$db2MediaRoot] or $!db2Version [$db2Version] not set! or $!db2License [$db2License] not set!"
        exitWithErrMsg "$errMsg"
      else
        db2ZipFileLocation=${mediaServer}"/"${db2MediaRoot}"/"${db2Version}"/"${db2License}
      fi
    fi
  fi

  ## using zipped up file
  if [ "X"$db2ZipFileLocation"X" == "XX" ]; then
    errMsg="$!db2ZipFileLocation [$db2ZipFileLocation] not set!"
    exitWithErrMsg "$errMsg"
  else
    echo "using remote file, [$db2ZipFileLocation]"
    zipFileName=$(basename $db2ZipFileLocation)
    
    ## download the zip (http) OR copy the zip (nfs)
    #downloadDir=${mediaRoot}"/"${db2MediaRoot}
    downloadDir=${QD_InternalMedia}"/"${db2MediaRoot}
    unzippedDir=${downloadDir}"/unzipped"
    mkdir -p ${downloadDir}
    mkdir -p ${unzippedDir}
    cd ${downloadDir}
    db2LicenseFolder=${downloadDir}
    tempStr=`echo ${db2ZipFileLocation} | cut -c -4`
    timestamp=`date +%s`
    echo "DEBUG (ready to get remote file) : current epoch time is ["$timestamp"] Sec"
    if [ "http" == $tempStr ]; then
      ## download the zip from the url
      downloadHttpZip $db2ZipFileLocation
      zipNeedsDeleted=TRUE
    else
      # only download a copy if NFS has been setup
      if [ "TRUE" == ${nfsEnabled} ]; then
        # copy the zip
        copyZip $db2ZipFileLocation
        zipNeedsDeleted=TRUE
      else
        # not moving so update
        db2LicenseFolder=${db2ZipFileFolder}
        ## - already done - # zipFileName=$(basename $db2ZipFileLocation)
      fi
    fi
    timestamp=`date +%s`
    echo "DEBUG (remote file got) : current epoch time is ["$timestamp"] Sec"
    
    # nothing to unzip
    
    # db2LicenseFolder=${downloadDir}
    db2LicenseFile=${zipFileName}
    db2LicenseFileLocation=${db2LicenseFolder}"/"${db2LicenseFile}
    echo "using file $!db2LicenseFileLocation [$db2LicenseFileLocation]"
    checkFileExists ${db2LicenseFileLocation}
  fi
fi


## =============================================================
## === exit if only creating a media server

if [ "TRUE" == $createMediaOnly ]; then
  echo "media server update done"
  exit 0
fi


## =============================================================
## === DEBUG early exit

if [ "TRUE" == $debugDoNotInstall ]; then
  echo "DEBUG: Exiting prior to installing DB2 license"
  exit 0
fi



## =============================================================
# list current licenses
echo "currently installed licenses"
$ibmQseDb2DirUnix/adm/db2licm -l
if [ $? -eq 0 ]; then 
  echo "installed licenses listed"
else
  errMsg="failed to list currently installed licenses"
  exitWithErrMsg "$errMsg"
fi


## =============================================================
# install required licenses
db2LicenseDir=/opt/ibm/db2/license
mkdir -p $db2LicenseDir
#db2License=db2awse_c.lic
cd $db2LicenseDir
echo "move to ["${db2LicenseDir}"]"
echo "Copy DB2 License..."
echo "from ["${db2LicenseFileLocation}"]"
echo "to ["${db2LicenseFile}"]"
cp ${db2LicenseFileLocation} ${db2LicenseFile}
checkFileExists ${db2LicenseFile}


# install license
echo "install DB2 License..."
$ibmQseDb2DirUnix/adm/db2licm -a $db2LicenseFile
if [ $? -eq 0 ]; then 
  echo "DB2 License installed"
else
  errMsg="failed to install DB2 License"
  exitWithErrMsg "$errMsg"
fi


# list licenses
echo "currently installed licenses"
$ibmQseDb2DirUnix/adm/db2licm -l
if [ $? -eq 0 ]; then 
  echo "installed licenses listed"
else
  errMsg="failed to list currently installed licenses"
  exitWithErrMsg "$errMsg"
fi


# create instance
echo "create DB2 instance"
$ibmQseDb2DirUnix/instance/db2icrt -a server -p $DB2PORT -u $ibmQseFence_User $ibmQseInst_User
if [ $? -eq 0 ]; then 
  echo "DB2 Instance created"
else
  errMsg="failed to create DB2 Instance"
  exitWithErrMsg "$errMsg"
fi


# set environment
echo "update / set DB2 environment"
su - $ibmQseInst_User -c ". /home/$ibmQseInst_User/sqllib/db2profile"
# process su command response
if [ $? -ne 0 ]; then
  errMsg="failed to update / set DB2 environment"
  exitWithErrMsg "$errMsg"
else
  echo "DB2 environment updated / set"
fi


# enable connections from remote clients
echo "enable TCPIP"
su - $ibmQseInst_User -c "db2set DB2COMM=TCPIP"
# process su command response
if [ $? -ne 0 ]; then
  errMsg="failed to enable TCPIP"
  exitWithErrMsg "$errMsg"
else
  echo "enabled TCPIP"
fi


# enable autorestart (after a server reboot)
echo "enable DB2 autorestart"
su - $ibmQseInst_User -c "db2set DB2AUTOSTART=YES"
# process su command response
if [ $? -ne 0 ]; then
  errMsg="failed to enable DB2 autorestart"
  exitWithErrMsg "$errMsg"
else
  echo "enabled DB2 autorestart"
fi


# start DB2
echo "start DB2"
su - $ibmQseInst_User -c "db2start"
# process su command response
if [ $? -ne 0 ]; then
  errMsg="failed to start DB2"
  exitWithErrMsg "$errMsg"
else
  echo "started DB2"
fi


# list environment settings
su - $ibmQseInst_User -c "db2set -all"
# process su command response
if [ $? -ne 0 ]; then
  errMsg="failed to list DB2 environment settings"
  exitWithErrMsg "$errMsg"
else
  echo "listed DB2 environment settings"
fi


# tidy up by deleting anything downloaded or unzipped
# ===================================================
if [ "TRUE" == $zipNeedsDeleted ]; then
  echo "Removing the downloaded license ["${db2LicenseFileLocation}"]"
  rm -f ${db2LicenseFileLocation}
fi


## =======================================================
## === finished ====
timestamp=`date +%s`
echo "DEBUG (EOF) : current epoch time is ["$timestamp"] Sec"
echo "SUCCESS: installation complete"
exit 0