#!/bin/bash
#********************************************************************************
# Licensed Materials - Property of IBM
# (c) Copyright IBM Corporation 2015. All Rights Reserved.
#  
# U.S. Government Users Restricted Rights:
# Use, duplication or disclosure restricted by GSA ADP Schedule
# Contract with IBM Corp.
#
#********************************************************************************



#############
## FUNCTIONS 
#############

setDefaultInputs()
{
  USERNAME="defaultUSERNAME"
  USERPASSWORD="defaultUSERPASSWORD"
  UCDSERVER="defaultUCDSERVER"
  COMPONENTNAME="defaultCOMPONENTNAME"
  COMPONENTVERSION="defaultCOMPONENTVERSION"
  BASEFOLDER="defaultBASEFOLDER"
}


checkDefaultInputs()
{
  
  if [ "$USERNAME" == "defaultUSERNAME" ]; then
    errMsg="USERNAME [$USERNAME] still contains its default value"
    exitWithErrMsg "$errMsg"
  fi
  if [ "$USERPASSWORD" == "defaultUSERPASSWORD" ]; then
    errMsg="USERPASSWORD [$USERPASSWORD] still contains its default value"
    exitWithErrMsg "$errMsg"
  fi
  if [ "$UCDSERVER" == "defaultUCDSERVER" ]; then
    errMsg="UCDSERVER [$UCDSERVER] still contains its default value"
    exitWithErrMsg "$errMsg"
  fi
  if [ "$COMPONENTNAME" == "defaultCOMPONENTNAME" ]; then
    errMsg="COMPONENTNAME [$COMPONENTNAME] still contains its default value"
    exitWithErrMsg "$errMsg"
  fi
  if [ "$COMPONENTVERSION" == "defaultCOMPONENTVERSION" ]; then
    errMsg="COMPONENTVERSION [$COMPONENTVERSION] still contains its default value"
    exitWithErrMsg "$errMsg"
  fi
  if [ "$BASEFOLDER" == "defaultBASEFOLDER" ]; then
    errMsg="BASEFOLDER [$BASEFOLDER] still contains its default value"
    exitWithErrMsg "$errMsg"
  fi
}

exitWithErrMsg()
{
  tempString=$1
  echo "-- ERROR [${scriptName}] --"
  echo "-- message: $tempString"
  exit 1
}


checkFileExists()
{
  tempFile=$1
  if [ -f $tempFile ]; then
    echo "  file [$tempFile] exists"
  else
    errMsg="file [$tempFile] does not exist"
    exitWithErrMsg "$errMsg"
  fi
}


checkFolderExists()
{
  tempFolder=$1
  if [ -d $tempFolder ]; then
    echo "  folder [$tempFolder] located"
  else
    errMsg="[$tempFolder] does not exist"
    exitWithErrMsg "$errMsg"
  fi
}


checkFolderPopulated()
{
  # folder=$1
  tempFileCount=`ls $1 | wc -w`
  if [ $tempFileCount -eq 0 ]; then
    ls $1
    errMsg="expected [$1] to be populated, found [$tempFileCount] files"
    exitWithErrMsg "$errMsg"
  else
    echo "folder [$1] is populated"
  fi
}


# will assume these are globals
# $USERNAME
# $USERPASSWORD
# $UCDSERVER
# $UCDCLIEXE
addComponentVersion()
{
  componentName=$1
  componentVersionName=$2
  
  echo "  adding version ["${componentVersionName}"] to component ["${componentName}"]"
  COMMAND=${UCDCLIEXE}" -username "${USERNAME}" -password "${USERPASSWORD}" -weburl "${UCDSERVER}" createVersion -component "${componentName}" -name "${componentVersionName}
  # echo COMMAND: [${COMMAND}]
  # execute the command
  # -- success and ucd returns a json representation of the resource
  # -- failure and no json is returned
  $COMMAND
  errCode=$?
  if [ $errCode == 0 ]; then
    echo "  successfuly created component version"
  else
    errMsg="[$errCode] failed to add version"
    exitWithErrMsg "$errMsg"
  fi
}


# will assume these are globals
# $USERNAME
# $USERPASSWORD
# $UCDSERVER
# $UCDCLIEXE
addVersionFiles()
{
  componentName=$1
  componentVersionName=$2
  filesFolder=$3
  
  echo "  adding the files from ["${filesFolder}"] for version ["${componentVersionName}"] to component ["${componentName}"]"
  COMMAND=${UCDCLIEXE}" -username "${USERNAME}" -password "${USERPASSWORD}" -weburl "${UCDSERVER}" addVersionFiles -component "${componentName}" -version "${componentVersionName}" -base "${filesFolder}
  # echo COMMAND: [${COMMAND}]
  # execute the command
  $COMMAND
  errCode=$?
  if [ $errCode == 0 ]; then
    echo "  successful" 
  else
    errMsg="[$errCode] failed to add files"
    exitWithErrMsg "$errMsg"
  fi
}

####################
##                ##
## ==== MAIN ==== ##
##                ##
####################


# UCDCLIEXE="./udclient"

workingDir=`pwd -P`
scriptName=$0

# -- set default values
echo "setting default inputs values"
setDefaultInputs

# -- process inputs
echo "reading inputs values"
if [ $# != 6 ]; then
  echo "ERROR: script "${scriptName}" requires 6 arguments: USERNAME=<UserName> USERPASSWORD=<UserPassword> UCDSERVER=<UCDURL ex:https://UCDHostName:8443> COMPONENTNAME=<ComponentName> COMPONENTVERSION=<NewComponentVersion> BASEFOLDER=<folder containing scripts to import>"
  exit 1
fi

while [[ $# > 0 ]]; do
   key=`echo $1 | cut -d'=' -f 1`
   value=`echo $1 | cut -d'=' -f 1 --complement`
   echo "[$key] [$value]"
   if [ "USERNAME"  == "$key" ]; then
      USERNAME=$value
   fi
   if [ "USERPASSWORD"  == "$key" ]; then
      USERPASSWORD=$value
   fi
   if [ "UCDSERVER"  == "$key" ]; then
      UCDSERVER=$value
   fi
   if [ "COMPONENTNAME"  == "$key" ]; then
      COMPONENTNAME=$value
   fi
   if [ "COMPONENTVERSION"  == "$key" ]; then
      COMPONENTVERSION=$value
   fi
   if [ "BASEFOLDER"  == "$key" ]; then
      BASEFOLDER=$value
   fi

   shift
done

# -- check all the defaults changed
echo "checking default inputs values are updated"
checkDefaultInputs

echo "Check ["${BASEFOLDER}"] exists and has content"
checkFolderExists ${BASEFOLDER}
checkFolderPopulated ${BASEFOLDER}


# -- ucd cli client needs JAVA_HOME set, so check it exists
echo "JAVA_HOME currently [${JAVA_HOME}]"
if [ "" == "${JAVA_HOME}" ]; then
  errMsg="You must have JAVA_HOME set on your environment to use the uDeploy client."
  exitWithErrMsg "$errMsg"
else
  echo "check [${JAVA_HOME}] folder exists"
  checkFolderExists ${JAVA_HOME}
fi

# -- check the ucd cli client exists
echo "check the ucd cli client exists"
echo "UCDCLIEXE currently [${UCDCLIEXE}]"
if [ "" == "${UCDCLIEXE}" ]; then
  errMsg="You must have the location of the ucd cli client [UCDCLIEXE] set (exported) on your environment."
  exitWithErrMsg "$errMsg"
else
  echo "check [${UCDCLIEXE}] file exists"
  checkFileExists ${UCDCLIEXE}
fi

# -- add new component version including scripts
echo "add new component version including scripts"
echo "  -- ${COMPONENTNAME} add version"
addComponentVersion ${COMPONENTNAME} ${COMPONENTVERSION}

echo "  -- ${COMPONENTNAME} add files"
addVersionFiles ${COMPONENTNAME} ${COMPONENTVERSION} ${BASEFOLDER}

echo "SUCCESS [${scriptName}]: new component version including scripts added to UCD"
exit 0
