#!/bin/bash
#********************************************************************************
# Licensed Materials - Property of IBM
# IBM Quick Deployer
# (c) Copyright IBM Corporation 2015. All Rights Reserved.
#  
# U.S. Government Users Restricted Rights:
# Use, duplication or disclosure restricted by GSA ADP Schedule
# Contract with IBM Corp.
#
#********************************************************************************



#############
## FUNCTIONS 
#############


setDefaultInputs()
{
  USERNAME="defaultUSERNAME"
  USERPASSWORD=="defaultUSERPASSWORD"
  UCDSERVER="defaultUCDSERVER"
  COMPONENTNAME="defaultCOMPONENTNAME"
  COMPONENTOLDVERSION="defaultCOMPONENTOLDVERSION"
  COMPONENTNEWVERSION="defaultCOMPONENTNEWVERSION"
  DEFAULTFILESOURCEFOLDER="defaultDEFAULTFILESOURCEFOLDER"
}


checkDefaultInputs()
{
  
  if [ "$USERNAME" == "defaultUSERNAME" ]; then
    errMsg="USERNAME [$USERNAME] still contains its default value"
    exitWithErrMsg "$errMsg"
  fi
  if [ "$USERPASSWORD" == "defaultUSERPASSWORD" ]; then
    errMsg="USERPASSWORD [$USERPASSWORD] still contains its default value"
    exitWithErrMsg "$errMsg"
  fi
  if [ "$UCDSERVER" == "defaultUCDSERVER" ]; then
    errMsg="UCDSERVER [$UCDSERVER] still contains its default value"
    exitWithErrMsg "$errMsg"
  fi
  if [ "$COMPONENTNAME" == "defaultCOMPONENTNAME" ]; then
    errMsg="COMPONENTNAME [$COMPONENTNAME] still contains its default value"
    exitWithErrMsg "$errMsg"
  fi
  if [ "$COMPONENTOLDVERSION" == "defaultCOMPONENTOLDVERSION" ]; then
    errMsg="COMPONENTOLDVERSION [$COMPONENTOLDVERSION] still contains its default value"
    exitWithErrMsg "$errMsg"
  fi
  if [ "$COMPONENTNEWVERSION" == "defaultCOMPONENTNEWVERSION" ]; then
    errMsg="COMPONENTNEWVERSION [$COMPONENTNEWVERSION] still contains its default value"
    exitWithErrMsg "$errMsg"
  fi
  if [ "$DEFAULTFILESOURCEFOLDER" == "defaultDEFAULTFILESOURCEFOLDER" ]; then
    errMsg="DEFAULTFILESOURCEFOLDER [$DEFAULTFILESOURCEFOLDER] still contains its default value"
    exitWithErrMsg "$errMsg"
  fi
}


exitWithErrMsg()
{
  tempString=$1
  echo "-- ERROR [${scriptName}] --"
  echo "-- message: $tempString"
  exit 1
}


checkFileExists()
{
  tempFile=$1
  if [ -f $tempFile ]; then
    echo "  file [$tempFile] exists"
  else
    errMsg="file [$tempFile] does not exist"
    exitWithErrMsg "$errMsg"
  fi
}


checkFolderExists()
{
  tempFolder=$1
  if [ -d $tempFolder ]; then
    echo "  folder [$tempFolder] located"
  else
    errMsg="[$tempFolder] does not exist"
    exitWithErrMsg "$errMsg"
  fi
}


addNewDefaultFiles()
{
  fileSourceFolder=$1
  fileDestinationFolder=$2
  fileName=$3
  echo "   Source: [${fileSourceFolder}/$fileName]"
  echo "   Destination:[${fileDestinationFolder}/$fileName]"
  if [ -f ${fileSourceFolder}/$fileName ]
  then
    cp -f ${fileSourceFolder}/$fileName ${fileDestinationFolder}/$fileName
    if [ $? == 0 ]; then
       echo "  successful"
    else
       errMsg="failed to copy [${fileSourceFolder}/$fileName] to [${fileDestinationFolder}/$fileName]"
       exitWithErrMsg "$errMsg"
    fi
   else
      echo "   Source file [${fileSourceFolder}/$fileName] does not exist, no update for the file"
  fi
}


unzipZip()
{
  zipFile=$1
  targetDir=$2
  
  unzip ${zipFile} -d ${targetDir}
  if [ $? == 0 ]; then
    echo "  unzip successful" 
  else
    errMsg="failed to unzip  ["${zipFile}"]"
    exitWithErrMsg "$errMsg"
  fi
}


## usage recursively deleteFolder (force)
deleteFolder()
{
  tempFolder=$1
  
  if [ -d ${tempFolder} ]; then
    echo "delete folder ["${tempFolder}"]"
    rm -Rf ${tempFolder}
    if [ -d ${tempFolder} ]; then
      errMsg="failed to delete folder"
      exitWithErrMsg "${errMsg}"
    else
      echo "succesfully deleted [${tempFolder}]"
    fi
  else
    echo "folder [${tempFolder}] does not exist, so cannot be deleted"
  fi
}

####################
##                ##
## ==== MAIN ==== ##
##                ##
####################

# UCDCLIEXE="./udclient"
BaseDir="./unzipped"
workingDir=`pwd -P`
scriptName=$0

# -- set default values
echo "setting default inputs values"
setDefaultInputs

# -- process inputs
echo "reading inputs values"
if [ $# != 7 ]; then
  echo "ERROR: script "${scriptName}" requires 7 arguments: USERNAME=<UserName> USERPASSWORD=<UserPassword> UCDSERVER=<UCDURL ex:https://UCDHostName:8443> COMPONENTNAME=<ComponentName> COMPONENTOLDVERSION=<ExistingComponentVersion> COMPONENTNEWVERSION=<NewComponentVersion> DEFAULTFILESOURCEFOLDER=<FolderIncludesDefaultFileToBeAddedIntoComponent>"
  exit 1
fi

while [[ $# > 0 ]]; do
   key=`echo $1 | cut -d'=' -f 1`
   value=`echo $1 | cut -d'=' -f 1 --complement`
   echo "[$key] [$value]"
   if [ "USERNAME"  == "$key" ]; then
      USERNAME=$value
   fi
   if [ "USERPASSWORD"  == "$key" ]; then
      USERPASSWORD=$value
   fi
   if [ "UCDSERVER"  == "$key" ]; then
      UCDSERVER=$value
   fi
   if [ "COMPONENTNAME"  == "$key" ]; then
      COMPONENTNAME=$value
   fi
   if [ "COMPONENTOLDVERSION"  == "$key" ]; then
      COMPONENTOLDVERSION=$value
   fi
   if [ "COMPONENTNEWVERSION"  == "$key" ]; then
      COMPONENTNEWVERSION=$value
   fi
   if [ "DEFAULTFILESOURCEFOLDER"  == "$key" ]; then
      DEFAULTFILESOURCEFOLDER=$value
   fi

   shift
done

# -- check all the defaults changed
echo "checking default inputs values are updated"
checkDefaultInputs

# -- check new files folder exists
echo "Check ["${DEFAULTFILESOURCEFOLDER}"] exists"
checkFolderExists ${DEFAULTFILESOURCEFOLDER}

# -- ucd cli client needs JAVA_HOME set, so check it exists
echo "JAVA_HOME currently [${JAVA_HOME}]"
if [ "" == "${JAVA_HOME}" ]; then
  errMsg="You must have JAVA_HOME set on your environment to use the uDeploy client."
  exitWithErrMsg "$errMsg"
else
  echo "check [${JAVA_HOME}] folder exists"
  checkFolderExists ${JAVA_HOME}
fi

# -- check the ucd cli client exists
echo "check the ucd cli client exists"
echo "UCDCLIEXE currently [${UCDCLIEXE}]"
if [ "" == "${UCDCLIEXE}" ]; then
  errMsg="You must have the location of the ucd cli client [UCDCLIEXE] set (exported) on your environment."
  exitWithErrMsg "$errMsg"
else
  echo "check [${UCDCLIEXE}] file exists"
  checkFileExists ${UCDCLIEXE}
fi

# -- download component zip file
echo "download scripts (as a zip) from component [${COMPONENTNAME}] version [${COMPONENTOLDVERSION}] to current folder"
sh ./componentVersionDownload.sh USERNAME=$USERNAME USERPASSWORD=$USERPASSWORD UCDSERVER=$UCDSERVER COMPONENTNAME=$COMPONENTNAME COMPONENTVERSION=$COMPONENTOLDVERSION

if [ $? == 0 ]; then
  echo "== done" 
else
  errMsg="failed to download component version including scripts"
  exitWithErrMsg "$errMsg"
fi


# -- delete the temp unzip folder
echo "delete existing temp folder content (unzipped scripts) [${BaseDir}]"
deleteFolder ${BaseDir} 


# -- unzip the downloaded artifact
echo "unziping to the temp folder [${BaseDir}]"
unzipZip ${COMPONENTNAME}_${COMPONENTOLDVERSION}_artifacts.zip ${BaseDir}

# -- add the new files to the zip
addNewDefaultFiles $DEFAULTFILESOURCEFOLDER "${BaseDir}/AutomationPrep/Linux/DatabaseParameters" "DBParameter.properties"
addNewDefaultFiles $DEFAULTFILESOURCEFOLDER "${BaseDir}/AutomationPrep/Linux/UserParameters" "userCreds.properties"
addNewDefaultFiles $DEFAULTFILESOURCEFOLDER "${BaseDir}/AutomationPrep/Common/CustomLDAP" "Custom_LDAPSecurity.properties"

# -- add new component version including scripts
echo "add new component [${COMPONENTNAME}] version [${COMPONENTNEWVERSION}] including scripts"
sh ./componentVersionImport.sh USERNAME=$USERNAME USERPASSWORD=$USERPASSWORD UCDSERVER=$UCDSERVER COMPONENTNAME=$COMPONENTNAME COMPONENTVERSION=$COMPONENTNEWVERSION BASEFOLDER=${BaseDir}
if [ $? == 0 ]; then
  echo "== done" 
else
  errMsg="failed to add new component version including scripts"
  exitWithErrMsg "$errMsg"
fi


echo "SUCCESS [${scriptName}]: component scripts updated and a new version added to UCD"
exit 0
